% Auto-generated chapter 4 for bukhari
% Hadiths in this chapter: 113

\hadithdefcmd{bukhari}{135}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْبَلُ صَلاَةُ مَنْ أَحْدَثَ حَتَّى يَتَوَضَّأَ ‏"‏‏.‏ قَالَ رَجُلٌ مِنْ حَضْرَمَوْتَ مَا الْحَدَثُ يَا أَبَا هُرَيْرَةَ قَالَ فُسَاءٌ أَوْ ضُرَاطٌ‏.‏\hadithno{135}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The prayer of a person who does Hadath (passes urine, stool or wind) is not accepted till he performs the ablution." A person from Hadaramout asked Abu Huraira, "What is 'Hadath'?" Abu Huraira replied, " 'Hadath' means the passing of wind}}
\hadithdefcmd{bukhari}{136}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ نُعَيْمٍ الْمُجْمِرِ، قَالَ رَقِيتُ مَعَ أَبِي هُرَيْرَةَ عَلَى ظَهْرِ الْمَسْجِدِ، فَتَوَضَّأَ فَقَالَ إِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أُمَّتِي يُدْعَوْنَ يَوْمَ الْقِيَامَةِ غُرًّا مُحَجَّلِينَ مِنْ آثَارِ الْوُضُوءِ، فَمَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يُطِيلَ غُرَّتَهُ فَلْيَفْعَلْ ‏"‏‏.‏\hadithno{136}\hadithtrans{Narrated Nu`am Al-Mujmir:Once I went up the roof of the mosque, along with Abu Huraira. He performed ablution and said, "I heard the Prophet (ﷺ) saying, "On the Day of Resurrection, my followers will be called "Al-Ghurr-ul- Muhajjalun" from the trace of ablution and whoever can increase the area of his radiance should do so (i.e. by performing ablution regularly)}}
\hadithdefcmd{bukhari}{137}{حَدَّثَنَا عَلِيٌّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ شَكَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الرَّجُلُ الَّذِي يُخَيَّلُ إِلَيْهِ أَنَّهُ يَجِدُ الشَّىْءَ فِي الصَّلاَةِ‏.‏ فَقَالَ ‏ "‏ لاَ يَنْفَتِلْ ـ أَوْ لاَ يَنْصَرِفْ ـ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏‏.‏\hadithno{137}\hadithtrans{Narrated `Abbad bin Tamim:My uncle asked Allah's Messenger (ﷺ) about a person who imagined to have passed wind during the prayer. Allah's Apostle replied: "He should not leave his prayers unless he hears sound or smells something}}
\hadithdefcmd{bukhari}{138}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ أَخْبَرَنِي كُرَيْبٌ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَامَ حَتَّى نَفَخَ ثُمَّ صَلَّى ـ وَرُبَّمَا قَالَ اضْطَجَعَ حَتَّى نَفَخَ ـ ثُمَّ قَامَ فَصَلَّى‏.‏ ثُمَّ حَدَّثَنَا بِهِ سُفْيَانُ مَرَّةً بَعْدَ مَرَّةٍ عَنْ عَمْرٍو عَنْ كُرَيْبٍ عَنِ ابْنِ عَبَّاسٍ قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ لَيْلَةً، فَقَامَ النَّبِيُّ صلى الله عليه وسلم مِنَ اللَّيْلِ، فَلَمَّا كَانَ فِي بَعْضِ اللَّيْلِ قَامَ النَّبِيُّ صلى الله عليه وسلم فَتَوَضَّأَ مِنْ شَنٍّ مُعَلَّقٍ وُضُوءًا خَفِيفًا ـ يُخَفِّفُهُ عَمْرٌو وَيُقَلِّلُهُ ـ وَقَامَ يُصَلِّي فَتَوَضَّأْتُ نَحْوًا مِمَّا تَوَضَّأَ، ثُمَّ جِئْتُ فَقُمْتُ عَنْ يَسَارِهِ ـ وَرُبَّمَا قَالَ سُفْيَانُ عَنْ شِمَالِهِ ـ فَحَوَّلَنِي فَجَعَلَنِي عَنْ يَمِينِهِ، ثُمَّ صَلَّى مَا شَاءَ اللَّهُ، ثُمَّ اضْطَجَعَ، فَنَامَ حَتَّى نَفَخَ، ثُمَّ أَتَاهُ الْمُنَادِي فَآذَنَهُ بِالصَّلاَةِ، فَقَامَ مَعَهُ إِلَى الصَّلاَةِ، فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏ قُلْنَا لِعَمْرٍو إِنَّ نَاسًا يَقُولُونَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَنَامُ عَيْنُهُ وَلاَ يَنَامُ قَلْبُهُ‏.‏ قَالَ عَمْرٌو سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ يَقُولُ رُؤْيَا الأَنْبِيَاءِ وَحْىٌ، ثُمَّ قَرَأَ ‏\{‏إِنِّي أَرَى فِي الْمَنَامِ أَنِّي أَذْبَحُكَ‏\}‏‏.‏\hadithno{138}\hadithtrans{Narrated Kuraib:Ibn `Abbas said, "The Prophet (ﷺ) slept till he snored and then prayed (or probably lay till his breath sounds were heard and then got up and prayed)." Ibn `Abbas added: "I stayed overnight in the house of my aunt, Maimuna, the Prophet (ﷺ) slept for a part of the night, (See Fath-al-Bari page 249, Vol. 1), and late in the night, he got up and performed ablution from a hanging water skin, a light (perfect) ablution and stood up for the prayer. I, too, performed a similar ablution, then I went and stood on his left. He drew me to his right and prayed as much as Allah wished, and again lay and slept till his breath sounds were heard. Later on the Mu'adh-dhin (call maker for the prayer) came to him and informed him that it was time for Prayer. The Prophet (ﷺ) went with him for the prayer without performing a new ablution." (Sufyan said to `Amr that some people said, "The eyes of Allah's Messenger (ﷺ) sleep but his heart does not sleep." `Amr replied, "I heard `Ubaid bin `Umar saying that the dreams of Prophets were Divine Inspiration, and then he recited the verse: 'I (Abraham) see in a dream, (O my son) that I offer you in sacrifice (to Allah)." (37.102) (See Hadith No)}}
\hadithdefcmd{bukhari}{139}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سَمِعَهُ يَقُولُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ حَتَّى إِذَا كَانَ بِالشِّعْبِ نَزَلَ فَبَالَ، ثُمَّ تَوَضَّأَ وَلَمْ يُسْبِغِ الْوُضُوءَ‏.‏ فَقُلْتُ الصَّلاَةَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏‏.‏ فَرَكِبَ، فَلَمَّا جَاءَ الْمُزْدَلِفَةَ نَزَلَ فَتَوَضَّأَ، فَأَسْبَغَ الْوُضُوءَ، ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْمَغْرِبَ، ثُمَّ أَنَاخَ كُلُّ إِنْسَانٍ بَعِيرَهُ فِي مَنْزِلِهِ، ثُمَّ أُقِيمَتِ الْعِشَاءُ فَصَلَّى وَلَمْ يُصَلِّ بَيْنَهُمَا‏.‏\hadithno{139}\hadithtrans{Narrated Usama bin Zaid:Allah's Messenger (ﷺ) proceeded from `Arafat till when he reached the mountain pass, he dismounted, urinated and then performed ablution but not a perfect one. I said to him, ("Is it the time for) the prayer, O Allah's Messenger (ﷺ)?" He said, "The (place of) prayer is ahead of you." He rode till when he reached Al-Muzdalifa, he dismounted and performed ablution and a perfect one, The (call for) Iqama was pronounced and he led the Maghrib prayer. Then everybody made his camel kneel down at its place. Then the Iqama was pronounced for the `Isha' prayer which the Prophet (ﷺ) led and no prayer was offered in between the two . prayers (`Isha' and Maghrib)}}
\hadithdefcmd{bukhari}{140}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَخْبَرَنَا أَبُو سَلَمَةَ الْخُزَاعِيُّ، مَنْصُورُ بْنُ سَلَمَةَ قَالَ أَخْبَرَنَا ابْنُ بِلاَلٍ ـ يَعْنِي سُلَيْمَانَ ـ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ تَوَضَّأَ فَغَسَلَ وَجْهَهُ، ثُمَّ أَخَذَ غَرْفَةً مِنْ مَاءٍ، فَمَضْمَضَ بِهَا وَاسْتَنْشَقَ، ثُمَّ أَخَذَ غَرْفَةً مِنْ مَاءٍ، فَجَعَلَ بِهَا هَكَذَا، أَضَافَهَا إِلَى يَدِهِ الأُخْرَى، فَغَسَلَ بِهِمَا وَجْهَهُ، ثُمَّ أَخَذَ غَرْفَةً مِنْ مَاءٍ، فَغَسَلَ بِهَا يَدَهُ الْيُمْنَى، ثُمَّ أَخَذَ غَرْفَةً مِنْ مَاءٍ، فَغَسَلَ بِهَا يَدَهُ الْيُسْرَى، ثُمَّ مَسَحَ بِرَأْسِهِ، ثُمَّ أَخَذَ غَرْفَةً مِنْ مَاءٍ فَرَشَّ عَلَى رِجْلِهِ الْيُمْنَى حَتَّى غَسَلَهَا، ثُمَّ أَخَذَ غَرْفَةً أُخْرَى، فَغَسَلَ بِهَا رِجْلَهُ ـ يَعْنِي الْيُسْرَى ـ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ‏.‏\hadithno{140}\hadithtrans{Narrated `Ata' bin Yasar:Ibn `Abbas performed ablution and washed his face (in the following way): He ladled out a handful of water, rinsed his mouth and washed his nose with it by putting in water and then blowing it out. He then, took another handful (of water) and did like this (gesturing) joining both hands, and washed his face, took another handful of water and washed his right forearm. He again took another handful of water and washed his left forearm, and passed wet hands over his head and took another handful of water and poured it over his right foot (up to his ankles) and washed it thoroughly and similarly took another handful of water and washed thoroughly his left foot (up to the ankles) and said, "I saw Allah's Messenger (ﷺ) performing ablution in this way}}
\hadithdefcmd{bukhari}{141}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَتَى أَهْلَهُ قَالَ بِسْمِ اللَّهِ اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا‏.‏ فَقُضِيَ بَيْنَهُمَا وَلَدٌ، لَمْ يَضُرَّهُ ‏"‏‏.‏\hadithno{141}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If anyone of you on having sexual relations with his wife said (and he must say it before starting) 'In the name of Allah. O Allah! Protect us from Satan and also protect what you bestow upon us (i.e. the coming offspring) from Satan,' and if it is destined that they should have a child then, Satan will never be able to harm that offspring}}
\hadithdefcmd{bukhari}{142}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبُثِ وَالْخَبَائِثِ ‏"‏‏.‏ تَابَعَهُ ابْنُ عَرْعَرَةَ عَنْ شُعْبَةَ‏.‏ وَقَالَ غُنْدَرٌ عَنْ شُعْبَةَ إِذَا أَتَى الْخَلاَءَ‏.‏ وَقَالَ مُوسَى عَنْ حَمَّادٍ إِذَا دَخَلَ‏.‏ وَقَالَ سَعِيدُ بْنُ زَيْدٍ حَدَّثَنَا عَبْدُ الْعَزِيزِ إِذَا أَرَادَ أَنْ يَدْخُلَ‏.‏\hadithno{142}\hadithtrans{Narrated Anas:Whenever the Prophet (ﷺ) went to answer the call of nature, he used to say, "Allah-umma inni a`udhu bika minal khubuthi wal khaba'ith i.e. O Allah, I seek Refuge with You from all offensive and wicked things (evil deeds and evil spirits)}}
\hadithdefcmd{bukhari}{143}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنَا وَرْقَاءُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ الْخَلاَءَ، فَوَضَعْتُ لَهُ وَضُوءًا قَالَ ‏"‏ مَنْ وَضَعَ هَذَا ‏"‏‏.‏ فَأُخْبِرَ فَقَالَ ‏"‏ اللَّهُمَّ فَقِّهْهُ فِي الدِّينِ ‏"‏‏.‏\hadithno{143}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) entered a lavatory and I placed water for his ablution. He asked, "Who placed it?" He was informed accordingly and so he said, "O Allah! Make him (Ibn `Abbas) a learned scholar in religion (Islam)}}
\hadithdefcmd{bukhari}{144}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَى أَحَدُكُمُ الْغَائِطَ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يُوَلِّهَا ظَهْرَهُ، شَرِّقُوا أَوْ غَرِّبُوا ‏"‏‏.‏\hadithno{144}\hadithtrans{Narrated Abu Aiyub Al-Ansari:Allah's Messenger (ﷺ) said, "If anyone of you goes to an open space for answering the call of nature he should neither face nor turn his back towards the Qibla; he should either face the east or the west}}
\hadithdefcmd{bukhari}{145}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ إِنَّ نَاسًا يَقُولُونَ إِذَا قَعَدْتَ عَلَى حَاجَتِكَ، فَلاَ تَسْتَقْبِلِ الْقِبْلَةَ وَلاَ بَيْتَ الْمَقْدِسِ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَقَدِ ارْتَقَيْتُ يَوْمًا عَلَى ظَهْرِ بَيْتٍ لَنَا، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى لَبِنَتَيْنِ مُسْتَقْبِلاً بَيْتَ الْمَقْدِسِ لِحَاجَتِهِ‏.‏ وَقَالَ لَعَلَّكَ مِنَ الَّذِينَ يُصَلُّونَ عَلَى أَوْرَاكِهِمْ، فَقُلْتُ لاَ أَدْرِي وَاللَّهِ‏.‏ قَالَ مَالِكٌ يَعْنِي الَّذِي يُصَلِّي وَلاَ يَرْتَفِعُ عَنِ الأَرْضِ، يَسْجُدُ وَهُوَ لاَصِقٌ بِالأَرْضِ‏.‏\hadithno{145}\hadithtrans{Narrated `Abdullah bin `Umar:People say, "Whenever you sit for answering the call of nature, you should not face the Qibla or Baitul-Maqdis (Jerusalem)." I told them, "Once I went up the roof of our house and I saw Allah's Apostle answering the call of nature while sitting on two bricks facing Baitul-Maqdis (Jerusalem) (but there was a screen covering him. ' (Fath-al-Bari, Page 258, Vol)}}
\hadithdefcmd{bukhari}{146}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَزْوَاجَ النَّبِيِّ، صلى الله عليه وسلم كُنَّ يَخْرُجْنَ بِاللَّيْلِ إِذَا تَبَرَّزْنَ إِلَى الْمَنَاصِعِ ـ وَهُوَ صَعِيدٌ أَفْيَحُ ـ فَكَانَ عُمَرُ يَقُولُ لِلنَّبِيِّ صلى الله عليه وسلم احْجُبْ نِسَاءَكَ‏.‏ فَلَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْعَلُ، فَخَرَجَتْ سَوْدَةُ بِنْتُ زَمْعَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم لَيْلَةً مِنَ اللَّيَالِي عِشَاءً، وَكَانَتِ امْرَأَةً طَوِيلَةً، فَنَادَاهَا عُمَرُ أَلاَ قَدْ عَرَفْنَاكِ يَا سَوْدَةُ‏.‏ حِرْصًا عَلَى أَنْ يَنْزِلَ الْحِجَابُ، فَأَنْزَلَ اللَّهُ آيَةَ الْحِجَابِ‏.‏\hadithno{146}\hadithtrans{Narrated `Aisha:The wives of the Prophet (ﷺ) used to go to Al-Manasi, a vast open place (near Baqi` at Medina) to answer the call of nature at night. `Umar used to say to the Prophet (ﷺ) "Let your wives be veiled," but Allah's Apostle did not do so. One night Sauda bint Zam`a the wife of the Prophet (ﷺ) went out at `Isha' time and she was a tall lady. `Umar addressed her and said, "I have recognized you, O Sauda." He said so, as he desired eagerly that the verses of Al-Hijab (the observing of veils by the Muslim women) may be revealed. So Allah revealed the verses of "Al-Hijab" (A complete body cover excluding the eyes)}}
\hadithdefcmd{bukhari}{147}{حَدَّثَنَا زَكَرِيَّاءُ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَدْ أُذِنَ أَنْ تَخْرُجْنَ فِي حَاجَتِكُنَّ ‏"‏‏.‏ قَالَ هِشَامٌ يَعْنِي الْبَرَازَ‏.‏\hadithno{147}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said to his wives, "You are allowed to go out to answer the call of nature}}
\hadithdefcmd{bukhari}{148}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ وَاسِعِ بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ ارْتَقَيْتُ فَوْقَ ظَهْرِ بَيْتِ حَفْصَةَ لِبَعْضِ حَاجَتِي، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْضِي حَاجَتَهُ مُسْتَدْبِرَ الْقِبْلَةِ مُسْتَقْبِلَ الشَّأْمِ‏.‏\hadithno{148}\hadithtrans{Narrated `Abdullah bin `Umar:I went up to the roof of Hafsa's house for some job and I saw Allah's Messenger (ﷺ) answering the call of nature facing Sham (Syria, Jordan, Palestine and Lebanon regarded as one country) with his back towards the Qibla. (See Hadith No)}}
\hadithdefcmd{bukhari}{149}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَخْبَرَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، أَنَّ عَمَّهُ، وَاسِعَ بْنَ حَبَّانَ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ أَخْبَرَهُ قَالَ لَقَدْ ظَهَرْتُ ذَاتَ يَوْمٍ عَلَى ظَهْرِ بَيْتِنَا، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاعِدًا عَلَى لَبِنَتَيْنِ مُسْتَقْبِلَ بَيْتِ الْمَقْدِسِ‏.‏\hadithno{149}\hadithtrans{Narrated `Abdullah bin `Umar:Once I went up the roof of our house and saw Allah's Messenger (ﷺ) answering the call of nature while sitting over two bricks facing Baitul-Maqdis (Jerusalem). (See Hadith No)}}
\hadithdefcmd{bukhari}{150}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مُعَاذٍ ـ وَاسْمُهُ عَطَاءُ بْنُ أَبِي مَيْمُونَةَ ـ قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا خَرَجَ لِحَاجَتِهِ أَجِيءُ أَنَا وَغُلاَمٌ مَعَنَا إِدَاوَةٌ مِنْ مَاءٍ‏.‏ يَعْنِي يَسْتَنْجِي بِهِ‏.‏\hadithno{150}\hadithtrans{Narrated Anas bin Malik:Whenever Allah's Messenger (ﷺ) went to answer the call of nature, I along with another boy used to accompany him with a tumbler full of water. (Hisham commented, "So that he might wash his private parts with it)}}
\hadithdefcmd{bukhari}{151}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مُعَاذٍ ـ هُوَ عَطَاءُ بْنُ أَبِي مَيْمُونَةَ ـ قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَرَجَ لِحَاجَتِهِ تَبِعْتُهُ أَنَا وَغُلاَمٌ مِنَّا مَعَنَا إِدَاوَةٌ مِنْ مَاءٍ‏.‏\hadithno{151}\hadithtrans{Narrated Anas:Whenever Allah's Messenger (ﷺ) went to answer the call of nature, I along with another boy from us used to go behind him with a tumbler full of water}}
\hadithdefcmd{bukhari}{152}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ الْخَلاَءَ، فَأَحْمِلُ أَنَا وَغُلاَمٌ إِدَاوَةً مِنْ مَاءٍ، وَعَنَزَةً، يَسْتَنْجِي بِالْمَاءِ‏.‏ تَابَعَهُ النَّضْرُ وَشَاذَانُ عَنْ شُعْبَةَ‏.‏ الْعَنَزَةُ عَصًا عَلَيْهِ زُجٌّ‏.‏\hadithno{152}\hadithtrans{Narrated Anas bin Malik:Whenever Allah's Messenger (ﷺ) went to answer the call of nature, I along with another boy used to carry a tumbler full of water (for cleaning the private parts) and a short spear (or stick)}}
\hadithdefcmd{bukhari}{153}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ ـ هُوَ الدَّسْتَوَائِيُّ ـ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَرِبَ أَحَدُكُمْ فَلاَ يَتَنَفَّسْ فِي الإِنَاءِ، وَإِذَا أَتَى الْخَلاَءَ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ، وَلاَ يَتَمَسَّحْ بِيَمِينِهِ ‏"‏‏.‏\hadithno{153}\hadithtrans{Narrated Abu Qatada:Allah's Messenger (ﷺ) said, "Whenever anyone of you drinks water, he should not breathe in the drinking utensil, and whenever anyone of you goes to a lavatory, he should neither touch his penis nor clean his private parts with his right hand}}
\hadithdefcmd{bukhari}{154}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا بَالَ أَحَدُكُمْ فَلاَ يَأْخُذَنَّ ذَكَرَهُ بِيَمِينِهِ، وَلاَ يَسْتَنْجِي بِيَمِينِهِ، وَلاَ يَتَنَفَّسْ فِي الإِنَاءِ ‏"‏‏.‏\hadithno{154}\hadithtrans{Narrated Abu Qatada:The Prophet (ﷺ) said, "Whenever anyone of you makes water he should not hold his penis or clean his private parts with his right hand. (And while drinking) one should not breathe in the drinking utensil}}
\hadithdefcmd{bukhari}{155}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدِ بْنِ عَمْرٍو الْمَكِّيُّ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اتَّبَعْتُ النَّبِيَّ صلى الله عليه وسلم وَخَرَجَ لِحَاجَتِهِ، فَكَانَ لاَ يَلْتَفِتُ فَدَنَوْتُ مِنْهُ فَقَالَ ‏ "‏ ابْغِنِي أَحْجَارًا أَسْتَنْفِضْ بِهَا ـ أَوْ نَحْوَهُ ـ وَلاَ تَأْتِنِي بِعَظْمٍ وَلاَ رَوْثٍ ‏"‏‏.‏ فَأَتَيْتُهُ بِأَحْجَارٍ بِطَرَفِ ثِيَابِي فَوَضَعْتُهَا إِلَى جَنْبِهِ وَأَعْرَضْتُ عَنْهُ، فَلَمَّا قَضَى أَتْبَعَهُ بِهِنَّ‏.‏\hadithno{155}\hadithtrans{Narrated Abu Huraira:I followed the Prophet (ﷺ) while he was going out to answer the call of nature. He used not to look this way or that. So, when I approached near him he said to me, "Fetch for me some stones for ' cleaning the privates parts (or said something similar), and do not bring a bone or a piece of dung." So I brought the stones in the corner of my garment and placed them by his side and I then went away from him. When he finished (from answering the call of nature) he used, them}}
\hadithdefcmd{bukhari}{156}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ لَيْسَ أَبُو عُبَيْدَةَ ذَكَرَهُ وَلَكِنْ عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ، يَقُولُ أَتَى النَّبِيُّ صلى الله عليه وسلم الْغَائِطَ، فَأَمَرَنِي أَنْ آتِيَهُ بِثَلاَثَةِ أَحْجَارٍ، فَوَجَدْتُ حَجَرَيْنِ، وَالْتَمَسْتُ الثَّالِثَ فَلَمْ أَجِدْهُ، فَأَخَذْتُ رَوْثَةً، فَأَتَيْتُهُ بِهَا، فَأَخَذَ الْحَجَرَيْنِ وَأَلْقَى الرَّوْثَةَ وَقَالَ ‏ "‏ هَذَا رِكْسٌ ‏"‏‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ يُوسُفَ عَنْ أَبِيهِ عَنْ أَبِي إِسْحَاقَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ‏.‏\hadithno{156}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) went out to answer the call of nature and asked me to bring three stones. I found two stones and searched for the third but could not find it. So I took a dried piece of dung and brought it to him. He took the two stones and threw away the dung and said, "This is a filthy thing}}
\hadithdefcmd{bukhari}{157}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم مَرَّةً مَرَّةً‏.‏\hadithno{157}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) performed ablution by washing the body parts only once}}
\hadithdefcmd{bukhari}{158}{حَدَّثَنَا حُسَيْنُ بْنُ عِيسَى، قَالَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ مَرَّتَيْنِ مَرَّتَيْنِ‏.‏\hadithno{158}\hadithtrans{Narrated `Abdullah bin Zaid:The Prophet (ﷺ) performed ablution by washing the body parts twice}}
\hadithdefcmd{bukhari}{159}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَطَاءَ بْنَ يَزِيدَ، أَخْبَرَهُ أَنَّ حُمْرَانَ مَوْلَى عُثْمَانَ أَخْبَرَهُ أَنَّهُ، رَأَى عُثْمَانَ بْنَ عَفَّانَ دَعَا بِإِنَاءٍ، فَأَفْرَغَ عَلَى كَفَّيْهِ ثَلاَثَ مِرَارٍ فَغَسَلَهُمَا، ثُمَّ أَدْخَلَ يَمِينَهُ فِي الإِنَاءِ فَمَضْمَضَ، وَاسْتَنْشَقَ، ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا، وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ ثَلاَثَ مِرَارٍ، ثُمَّ مَسَحَ بِرَأْسِهِ، ثُمَّ غَسَلَ رِجْلَيْهِ ثَلاَثَ مِرَارٍ إِلَى الْكَعْبَيْنِ، ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا، ثُمَّ صَلَّى رَكْعَتَيْنِ، لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ، غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{159}\hadithtrans{Narrated Humran: (the slave of 'Uthman) I saw 'Uthman bin 'Affan asking for a tumbler of water (and when it was brought) he poured water over his hands and washed them thrice and then put his right hand in the water container and rinsed his mouth, washed his nose by putting water in it and then blowing it out. then he washed his face and forearms up to the elbows thrice, passed his wet hands over his head and washed his feet up to the ankles thrice. Then he said, "Allah's Messenger (ﷺ) said 'If anyone performs ablution like that of mine and offers a two-rak'at prayer during which he does not think of anything else (not related to the present prayer) then his past sins will be forgiven}}
\hadithdefcmd{bukhari}{160}{وَعَنْ إِبْرَاهِيمَ، قَالَ قَالَ صَالِحُ بْنُ كَيْسَانَ قَالَ ابْنُ شِهَابٍ وَلَكِنْ عُرْوَةُ يُحَدِّثُ عَنْ حُمْرَانَ،، فَلَمَّا تَوَضَّأَ عُثْمَانُ قَالَ أَلاَ أُحَدِّثُكُمْ حَدِيثًا لَوْلاَ آيَةٌ مَا حَدَّثْتُكُمُوهُ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَتَوَضَّأُ رَجُلٌ فَيُحْسِنُ وُضُوءَهُ، وَيُصَلِّي الصَّلاَةَ إِلاَّ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الصَّلاَةِ حَتَّى يُصَلِّيَهَا ‏"‏‏.‏ قَالَ عُرْوَةُ الآيَةُ ‏\{‏إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلْنَا مِنَ الْبَيِّنَاتِ‏\}‏‏.‏\hadithno{160}\hadithtrans{After performing the ablution 'Uthman said, "I am going to tell you a Hadith which I would not have told you, had I not been compelled by a certain Holy Verse (the sub narrator 'Urwa said:This verse is: "Verily, those who conceal the clear signs and the guidance which we have sent down...)" (2:159). I heard the Prophet (ﷺ) saying, 'If a man performs ablution perfectly and then offers the compulsory congregational prayer, Allah will forgive his sins committed between that (prayer) and the (next) prayer till he offers it}}
\hadithdefcmd{bukhari}{161}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو إِدْرِيسَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَلْيَسْتَنْثِرْ، وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏‏.‏\hadithno{161}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever performs ablution should clean his nose with water by putting the water in it and then blowing it out, and whoever cleans his private parts with stones should do it with odd number of stones}}
\hadithdefcmd{bukhari}{162}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَجْعَلْ فِي أَنْفِهِ ثُمَّ لِيَنْثُرْ، وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ، وَإِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلْيَغْسِلْ يَدَهُ قَبْلَ أَنْ يُدْخِلَهَا فِي وَضُوئِهِ، فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏‏.‏\hadithno{162}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If anyone of you performs ablution he should put water in his nose and then blow it out and whoever cleans his private parts with stones should do so with odd numbers. And whoever wakes up from his sleep should wash his hands before putting them in the water for ablution, because nobody knows where his hands were during sleep}}
\hadithdefcmd{bukhari}{163}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ تَخَلَّفَ النَّبِيُّ صلى الله عليه وسلم عَنَّا فِي سَفْرَةٍ سَافَرْنَاهَا، فَأَدْرَكَنَا وَقَدْ أَرْهَقْنَا الْعَصْرَ، فَجَعَلْنَا نَتَوَضَّأُ وَنَمْسَحُ عَلَى أَرْجُلِنَا، فَنَادَى بِأَعْلَى صَوْتِهِ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا‏.‏\hadithno{163}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) remained behind us on a journey. He joined us while we were performing ablution for the `Asr prayer which was overdue and we were just passing wet hands over our feet (not washing them thoroughly) so he addressed us in a loud voice saying twice , "Save your heels from the fire}}
\hadithdefcmd{bukhari}{164}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ أَنَّهُ رَأَى عُثْمَانَ دَعَا بِوَضُوءٍ، فَأَفْرَغَ عَلَى يَدَيْهِ مِنْ إِنَائِهِ، فَغَسَلَهُمَا ثَلاَثَ مَرَّاتٍ، ثُمَّ أَدْخَلَ يَمِينَهُ فِي الْوَضُوءِ، ثُمَّ تَمَضْمَضَ، وَاسْتَنْشَقَ، وَاسْتَنْثَرَ، ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ ثَلاَثًا، ثُمَّ مَسَحَ بِرَأْسِهِ، ثُمَّ غَسَلَ كُلَّ رِجْلٍ ثَلاَثًا، ثُمَّ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَوَضَّأُ نَحْوَ وُضُوئِي هَذَا وَقَالَ ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ صَلَّى رَكْعَتَيْنِ، لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ، غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{164}\hadithtrans{Narrated Humran:(the freed slave of `Uthman bin `Affan) I saw `Uthman bin `Affan asking (for a tumbler of water) to perform ablution (and when it was brought) he poured water from it over his hands and washed them thrice and then put his right hand in the water container and rinsed his mouth and washed his nose by putting water in it and then blowing it out. Then he washed his face thrice and (then) forearms up to the elbows thrice, then passed his wet hands over his head and then washed each foot thrice. After that `Uthman said, "I saw the Prophet (ﷺ) performing ablution like this of mine, and he said, 'If anyone performs ablution like that of mine and offers a two-rak`at prayer during which he does not think of anything else (not related to the present prayer) then his past sins will be forgiven}}
\hadithdefcmd{bukhari}{165}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ وَكَانَ يَمُرُّ بِنَا وَالنَّاسُ يَتَوَضَّئُونَ مِنَ الْمِطْهَرَةِ ـ قَالَ أَسْبِغُوا الْوُضُوءَ فَإِنَّ أَبَا الْقَاسِمِ صلى الله عليه وسلم قَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏‏.‏\hadithno{165}\hadithtrans{Narrated Muhammad Ibn Ziyad:I heard Abu Huraira saying as he passed by us while the people were performing ablution from a utensil containing water, "Perform ablution perfectly and thoroughly for Abul-Qasim (the Prophet) said, 'Save your heels from the Hell-fire}}
\hadithdefcmd{bukhari}{166}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ يَا أَبَا عَبْدِ الرَّحْمَنِ، رَأَيْتُكَ تَصْنَعُ أَرْبَعًا لَمْ أَرَ أَحَدًا مِنْ أَصْحَابِكَ يَصْنَعُهَا‏.‏ قَالَ وَمَا هِيَ يَا ابْنَ جُرَيْجٍ قَالَ رَأَيْتُكَ لاَ تَمَسُّ مِنَ الأَرْكَانِ إِلاَّ الْيَمَانِيَيْنِ، وَرَأَيْتُكَ تَلْبَسُ النِّعَالَ السِّبْتِيَّةَ، وَرَأَيْتُكَ تَصْبُغُ بِالصُّفْرَةِ، وَرَأَيْتُكَ إِذَا كُنْتَ بِمَكَّةَ أَهَلَّ النَّاسُ إِذَا رَأَوُا الْهِلاَلَ وَلَمْ تُهِلَّ أَنْتَ حَتَّى كَانَ يَوْمُ التَّرْوِيَةِ‏.‏ قَالَ عَبْدُ اللَّهِ أَمَّا الأَرْكَانُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمَسُّ إِلاَّ الْيَمَانِيَيْنِ، وَأَمَّا النِّعَالُ السِّبْتِيَّةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُ النَّعْلَ الَّتِي لَيْسَ فِيهَا شَعَرٌ وَيَتَوَضَّأُ فِيهَا، فَأَنَا أُحِبُّ أَنْ أَلْبَسَهَا، وَأَمَّا الصُّفْرَةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبُغُ بِهَا، فَأَنَا أُحِبُّ أَنْ أَصْبُغَ بِهَا، وَأَمَّا الإِهْلاَلُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ حَتَّى تَنْبَعِثَ بِهِ رَاحِلَتُهُ‏.‏\hadithno{166}\hadithtrans{Narrated `Ubaid Ibn Juraij:I asked `Abdullah bin `Umar, "O Abu `Abdur-Rahman! I saw you doing four things which I never saw being done by anyone of you companions?" `Abdullah bin `Umar said, "What are those, O Ibn Juraij?" I said, "I never saw you touching any corner of the Ka`ba except these (two) facing south (Yemen) and I saw you wearing shoes made of tanned leather and dyeing your hair with Hinna (a kind of red dye). I also noticed that whenever you were in Mecca, the people assume Ihram on seeing the new moon crescent (1st of Dhul-Hijja) while you did not assume the Ihlal (Ihram) -(Ihram is also called Ihlal which means 'Loud calling' because a Muhrim has to recite Talbiya aloud when assuming the state of Ihram) - till the 8th of Dhul-Hijja (Day of Tarwiya). `Abdullah replied, "Regarding the corners of Ka`ba, I never saw Allah's Messenger (ﷺ) touching except those facing south (Yemen) and regarding the tanned leather shoes, no doubt I saw Allah's Messenger (ﷺ) wearing non-hairy shoes and he used to perform ablution while wearing the shoes (i.e. wash his feet and then put on the shoes). So I love to wear similar shoes. And about the dyeing of hair with Hinna; no doubt I saw Allah's Messenger (ﷺ) dyeing his hair with it and that is why I like to dye (my hair with it). Regarding Ihlal, I did not see Allah's Messenger (ﷺ) assuming Ihlal till he set out for Hajj (on the 8th of Dhul-Hijja)}}
\hadithdefcmd{bukhari}{167}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم لَهُنَّ فِي غُسْلِ ابْنَتِهِ ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏‏.‏\hadithno{167}\hadithtrans{Narrated Um-`Atiya:That the Prophet (ﷺ) at the time of washing his deceased daughter had said to them, "Start from the right side beginning with those parts which are washed in ablution}}
\hadithdefcmd{bukhari}{168}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَشْعَثُ بْنُ سُلَيْمٍ، قَالَ سَمِعْتُ أَبِي، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْجِبُهُ التَّيَمُّنُ فِي تَنَعُّلِهِ وَتَرَجُّلِهِ وَطُهُورِهِ وَفِي شَأْنِهِ كُلِّهِ‏.‏\hadithno{168}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like to start from the right side on wearing shoes, combing his hair and cleaning or washing himself and on doing anything else}}
\hadithdefcmd{bukhari}{169}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ، فَالْتَمَسَ النَّاسُ الْوَضُوءَ فَلَمْ يَجِدُوهُ، فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ الإِنَاءِ يَدَهُ، وَأَمَرَ النَّاسَ أَنْ يَتَوَضَّئُوا مِنْهُ‏.‏ قَالَ فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ‏.‏\hadithno{169}\hadithtrans{Narrated Anas bin Malik:I saw Allah's Messenger (ﷺ) when the `Asr prayer was due and the people searched for water to perform ablution but they could not find it. Later on (a pot full of) water for ablution was brought to Allah's Apostle. He put his hand in that pot and ordered the people to perform ablution from it. I saw the water springing out from underneath his fingers till all of them performed the ablution (it was one of the miracles of the Prophet)}}
\hadithdefcmd{bukhari}{170}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ عَاصِمٍ، عَنِ ابْنِ سِيرِينَ، قَالَ قُلْتُ لِعَبِيدَةَ عِنْدَنَا مِنْ شَعَرِ النَّبِيِّ صلى الله عليه وسلم أَصَبْنَاهُ مِنْ قِبَلِ أَنَسٍ، أَوْ مِنْ قِبَلِ أَهْلِ أَنَسٍ فَقَالَ لأَنْ تَكُونَ عِنْدِي شَعَرَةٌ مِنْهُ أَحَبُّ إِلَىَّ مِنَ الدُّنْيَا وَمَا فِيهَا‏.‏\hadithno{170}\hadithtrans{Narrated Ibn Seereen:I said to `Abida, "I have some of the hair of the Prophet (ﷺ) which I got from Anas or from his family." `Abida replied. "No doubt if I had a single hair of that it would have been dearer to me than the whole world and whatever is in it}}
\hadithdefcmd{bukhari}{171}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَخْبَرَنَا سَعِيدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَبَّادٌ، عَنِ ابْنِ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا حَلَقَ رَأْسَهُ كَانَ أَبُو طَلْحَةَ أَوَّلَ مَنْ أَخَذَ مِنْ شَعَرِهِ‏.‏\hadithno{171}\hadithtrans{Narrated Anas:When Allah's Messenger (ﷺ) got his head shaved, Abu- Talha was the first to take some of his hair}}
\hadithdefcmd{bukhari}{172}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعًا ‏"‏‏.‏\hadithno{172}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If a dog drinks from the utensil of anyone of you it is essential to wash it seven times}}
\hadithdefcmd{bukhari}{173}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، سَمِعْتُ أَبِي، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً رَأَى كَلْبًا يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ، فَأَخَذَ الرَّجُلُ خُفَّهُ فَجَعَلَ يَغْرِفُ لَهُ بِهِ حَتَّى أَرْوَاهُ، فَشَكَرَ اللَّهُ لَهُ فَأَدْخَلَهُ الْجَنَّةَ ‏"‏‏.‏\hadithno{173}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said, "A man saw a dog eating mud from (the severity of) thirst. So, that man took a shoe (and filled it) with water and kept on pouring the water for the dog till it quenched its thirst. So Allah approved of his deed and made him to enter Paradise}}
\hadithdefcmd{bukhari}{174}{وَقَالَ أَحْمَدُ بْنُ شَبِيبٍ حَدَّثَنَا أَبِي، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ كَانَتِ الْكِلاَبُ تَبُولُ وَتُقْبِلُ وَتُدْبِرُ فِي الْمَسْجِدِ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَكُونُوا يَرُشُّونَ شَيْئًا مِنْ ذَلِكَ‏.‏\hadithno{174}\hadithtrans{And narrated Hamza bin 'Abdullah:My father said. "During the lifetime of Allah's Apostle, the dogs used to urinate, and pass through the mosques (come and go), nevertheless they never used to sprinkle water on it (urine of the dog)}}
\hadithdefcmd{bukhari}{175}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ الْمُعَلَّمَ فَقَتَلَ فَكُلْ، وَإِذَا أَكَلَ فَلاَ تَأْكُلْ، فَإِنَّمَا أَمْسَكَهُ عَلَى نَفْسِهِ ‏"‏‏.‏ قُلْتُ أُرْسِلُ كَلْبِي فَأَجِدُ مَعَهُ كَلْبًا آخَرَ قَالَ ‏"‏ فَلاَ تَأْكُلْ، فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ، وَلَمْ تُسَمِّ عَلَى كَلْبٍ آخَرَ ‏"‏‏.‏\hadithno{175}\hadithtrans{Narrated `Adi bin Hatim:I asked the Prophet (about the hunting dogs) and he replied, "If you let loose (with Allah's name) your tamed dog after a game and it hunts it, you may eat it, but if the dog eats of (that game) then do not eat it because the dog has hunted it for itself." I further said, "Sometimes I send my dog for hunting and find another dog with it. He said, "Do not eat the game for you have mentioned Allah's name only on sending your dog and not the other dog}}
\hadithdefcmd{bukhari}{176}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ الْعَبْدُ فِي صَلاَةٍ مَا كَانَ فِي الْمَسْجِدِ يَنْتَظِرُ الصَّلاَةَ، مَا لَمْ يُحْدِثْ ‏"‏‏.‏ فَقَالَ رَجُلٌ أَعْجَمِيٌّ مَا الْحَدَثُ يَا أَبَا هُرَيْرَةَ قَالَ الصَّوْتُ‏.‏ يَعْنِي الضَّرْطَةَ‏.‏\hadithno{176}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A person is considered in prayer as long as he is waiting for the prayer in the mosque as long as he does not do Hadath." A non-Arab man asked, "O Abu Huraira! What is Hadath?" I replied, "It is the passing of wind (from the anus) (that is one of the types of Hadath)}}
\hadithdefcmd{bukhari}{177}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْصَرِفْ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏‏.‏\hadithno{177}\hadithtrans{Narrated `Abbad bin Tamim:My uncle said: The Prophet (ﷺ) said, "One should not leave his prayer unless he hears sound or smells something}}
\hadithdefcmd{bukhari}{178}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُنْذِرٍ أَبِي يَعْلَى الثَّوْرِيِّ، عَنْ مُحَمَّدٍ ابْنِ الْحَنَفِيَّةِ، قَالَ قَالَ عَلِيٌّ كُنْتُ رَجُلاً مَذَّاءً، فَاسْتَحْيَيْتُ أَنْ أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرْتُ الْمِقْدَادَ بْنَ الأَسْوَدِ فَسَأَلَهُ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ ‏"‏‏.‏ وَرَوَاهُ شُعْبَةُ عَنِ الأَعْمَشِ‏.‏\hadithno{178}\hadithtrans{Narrated `Ali:I used to get emotional urethral discharges frequently and felt shy to ask Allah's Messenger (ﷺ) about it. So I requested Al-Miqdad bin Al-Aswad to ask (the Prophet (ﷺ) ) about it. Al-Miqdad asked him and he replied, "One has to perform ablution (after it)}}
\hadithdefcmd{bukhari}{179}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنْ زَيْدَ بْنَ خَالِدٍ أَخْبَرَهُ أَنَّهُ، سَأَلَ عُثْمَانَ بْنَ عَفَّانَ ـ رضى الله عنه ـ قُلْتُ أَرَأَيْتَ إِذَا جَامَعَ فَلَمْ يُمْنِ قَالَ عُثْمَانُ يَتَوَضَّأُ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ، وَيَغْسِلُ ذَكَرَهُ‏.‏ قَالَ عُثْمَانُ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَسَأَلْتُ عَنْ ذَلِكَ عَلِيًّا، وَالزُّبَيْرَ، وَطَلْحَةَ، وَأُبَىَّ بْنَ كَعْبٍ ـ رضى الله عنهم ـ فَأَمَرُوهُ بِذَلِكَ‏.‏\hadithno{179}\hadithtrans{Narrated Zaid bin Khalid:I asked `Uthman bin `Affan about a person who engaged in intercourse but did no discharge. `Uthman replied, "He should perform ablution like the one for an ordinary prayer but he must wash his penis." `Uthman added, "I heard it from Allah's Messenger (ﷺ)." I asked `Ali Az-Zubair, Talha and Ubai bin Ka`b about it and they, too, gave the same reply. (This order was canceled later on and taking a bath became necessary for such cases)}}
\hadithdefcmd{bukhari}{180}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا النَّضْرُ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَكْوَانَ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْسَلَ إِلَى رَجُلٍ مِنَ الأَنْصَارِ فَجَاءَ وَرَأْسُهُ يَقْطُرُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَعَلَّنَا أَعْجَلْنَاكَ ‏"‏‏.‏ فَقَالَ نَعَمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أُعْجِلْتَ أَوْ قُحِطْتَ، فَعَلَيْكَ الْوُضُوءُ ‏"‏‏.‏ تَابَعَهُ وَهْبٌ قَالَ حَدَّثَنَا شُعْبَةُ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَلَمْ يَقُلْ غُنْدَرٌ وَيَحْيَى عَنْ شُعْبَةَ الْوُضُوءُ‏.‏\hadithno{180}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) sent for a Ansari man who came with water dropping from his head. The Prophet (ﷺ) said, "Perhaps we have forced you to hurry up, haven't we?" The Ansari replied, "Yes." Allah's Messenger (ﷺ) further said, "If you are forced to hurry up (during intercourse) or you do not discharge then ablution is due on you (This order was canceled later on, i.e. one has to take a bath)}}
\hadithdefcmd{bukhari}{181}{حَدَّثَنِي مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ يَحْيَى، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا أَفَاضَ مِنْ عَرَفَةَ عَدَلَ إِلَى الشِّعْبِ، فَقَضَى حَاجَتَهُ‏.‏ قَالَ أُسَامَةُ بْنُ زَيْدٍ فَجَعَلْتُ أَصُبُّ عَلَيْهِ وَيَتَوَضَّأُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتُصَلِّي فَقَالَ ‏ "‏ الْمُصَلَّى أَمَامَكَ ‏"‏‏.‏\hadithno{181}\hadithtrans{Narrated Usama bin Zaid:"When Allah's Messenger (ﷺ) departed from `Arafat, he turned towards a mountain pass where he answered the call of nature. (After he had finished) I poured water and he performed ablution and then I said to him, "O Allah's Messenger (ﷺ)! Will you offer the prayer?" He replied, "The Musalla (place of the prayer) is ahead of you (in Al-Muzdalifa)}}
\hadithdefcmd{bukhari}{182}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، قَالَ أَخْبَرَنِي سَعْدُ بْنُ إِبْرَاهِيمَ، أَنَّ نَافِعَ بْنَ جُبَيْرِ بْنِ مُطْعِمٍ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عُرْوَةَ بْنَ الْمُغِيرَةِ بْنِ شُعْبَةَ، يُحَدِّثُ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ، وَأَنَّهُ ذَهَبَ لِحَاجَةٍ لَهُ، وَأَنَّ مُغِيرَةَ جَعَلَ يَصُبُّ الْمَاءَ عَلَيْهِ، وَهُوَ يَتَوَضَّأُ، فَغَسَلَ وَجْهَهُ وَيَدَيْهِ وَمَسَحَ بِرَأْسِهِ وَمَسَحَ عَلَى الْخُفَّيْنِ‏.‏\hadithno{182}\hadithtrans{Narrated Al-Mughira bin Shu`ba:I was in the company of Allah's Messenger (ﷺ) on one of the journeys and he went out to answer the call of nature (and after he finished) I poured water and he performed ablution; he washed his face, forearms and passed his wet hand over his head and over the two Khuff (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{183}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، بَاتَ لَيْلَةً عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَهِيَ خَالَتُهُ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا انْتَصَفَ اللَّيْلُ، أَوْ قَبْلَهُ بِقَلِيلٍ أَوْ بَعْدَهُ بِقَلِيلٍ، اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ، ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ، ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ، فَتَوَضَّأَ مِنْهَا فَأَحْسَنَ وُضُوءَهُ، ثُمَّ قَامَ يُصَلِّي‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ، ثُمَّ ذَهَبْتُ، فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ يَدَهُ الْيُمْنَى عَلَى رَأْسِي، وَأَخَذَ بِأُذُنِي الْيُمْنَى، يَفْتِلُهَا، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ، ثُمَّ اضْطَجَعَ، حَتَّى أَتَاهُ الْمُؤَذِّنُ، فَقَامَ، فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{183}\hadithtrans{Narrated `Abdullah bin `Abbas:That he stayed overnight in the house of Maimuna the wife of the Prophet, his aunt. He added: I lay on the bed (cushion transversally) while Allah's Messenger (ﷺ) and his wife lay in the lengthwise direction of the cushion. Allah's Messenger (ﷺ) slept till the middle of the night, either a bit before or a bit after it and then woke up, rubbing the traces of sleep off his face with his hands. He then, recited the last ten verses of Sura Al-`Imran, got up and went to a hanging water-skin. He then Performed the ablution from it and it was a perfect ablution, and then stood up to offer the prayer. I, too, got up and did as the Prophet had done. Then I went and stood by his side. He placed his right hand on my head and caught my right ear and twisted it. He prayed two rak`at, then two rak`at and then two rak`at and then two rak`at and then two rak`at and then two rak`at (separately six times), and finally one rak`a (the witr). Then he lay down again in the bed till the Mu'adh-dhin came to him where upon the Prophet (ﷺ) got up, offered a two light rak`at prayer and went out and led the Fajr prayer}}
\hadithdefcmd{bukhari}{184}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنِ امْرَأَتِهِ، فَاطِمَةَ عَنْ جَدَّتِهَا، أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ أَنَّهَا قَالَتْ أَتَيْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حِينَ خَسَفَتِ الشَّمْسُ، فَإِذَا النَّاسُ قِيَامٌ يُصَلُّونَ، وَإِذَا هِيَ قَائِمَةٌ تُصَلِّي فَقُلْتُ مَا لِلنَّاسِ فَأَشَارَتْ بِيَدِهَا نَحْوَ السَّمَاءِ وَقَالَتْ سُبْحَانَ اللَّهِ‏.‏ فَقُلْتُ آيَةٌ فَأَشَارَتْ أَىْ نَعَمْ‏.‏ فَقُمْتُ حَتَّى تَجَلاَّنِي الْغَشْىُ، وَجَعَلْتُ أَصُبُّ فَوْقَ رَأْسِي مَاءً، فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ مَا مِنْ شَىْءٍ كُنْتُ لَمْ أَرَهُ إِلاَّ قَدْ رَأَيْتُهُ فِي مَقَامِي هَذَا حَتَّى الْجَنَّةِ وَالنَّارِ، وَلَقَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ مِثْلَ أَوْ قَرِيبًا مِنْ فِتْنَةِ الدَّجَّالِ ـ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ يُؤْتَى أَحَدُكُمْ فَيُقَالُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ ـ أَوِ الْمُوقِنُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ هُوَ مُحَمَّدٌ رَسُولُ اللَّهِ، جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى، فَأَجَبْنَا وَآمَنَّا وَاتَّبَعْنَا، فَيُقَالُ نَمْ صَالِحًا، فَقَدْ عَلِمْنَا إِنْ كُنْتَ لَمُؤْمِنًا، وَأَمَّا الْمُنَافِقُ ـ أَوِ الْمُرْتَابُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ لاَ أَدْرِي، سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏‏.‏\hadithno{184}\hadithtrans{Narrated Asma' bint Abu Bakr:I came to `Aisha the wife of the Prophet (ﷺ) during the solar eclipse. The people were standing and offering the prayer and she was also praying. I asked her, "What is wrong with the people?" She beckoned with her hand towards the sky and said, "Subhan Allah." I asked her, "Is there a sign?" She pointed out, "Yes." So I, too, stood for the prayer till I fell unconscious and later on I poured water on my head. After the prayer, Allah's Messenger (ﷺ) praised and glorified Allah and said, "Just now I have seen something which I never saw before at this place of mine, including Paradise and Hell. I have been inspired (and have understood) that you will be put to trials in your graves and these trials will be like the trials of Ad-Dajjal, or nearly like it (the sub narrator is not sure of what Asma' said). Angels will come to every one of you and ask, 'What do you know about this man?' A believer will reply, 'He is Muhammad, Allah's Messenger (ﷺ) , and he came to us with self-evident truth and guidance. So we accepted his teaching, believed and followed him.' Then the angels will say to him to sleep in peace as they have come to know that he was a believer. On the other hand a hypocrite or a doubtful person will reply, 'I do not know but heard the people saying something and so I said the same}}
\hadithdefcmd{bukhari}{185}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدٍ ـ وَهُوَ جَدُّ عَمْرِو بْنِ يَحْيَى ـ أَتَسْتَطِيعُ أَنْ تُرِيَنِي، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ فَقَالَ عَبْدُ اللَّهِ بْنُ زَيْدٍ نَعَمْ‏.‏ فَدَعَا بِمَاءٍ، فَأَفْرَغَ عَلَى يَدَيْهِ فَغَسَلَ يَدَهُ مَرَّتَيْنِ، ثُمَّ مَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا، ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا، ثُمَّ غَسَلَ يَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ، ثُمَّ مَسَحَ رَأْسَهُ بِيَدَيْهِ، فَأَقْبَلَ بِهِمَا وَأَدْبَرَ، بَدَأَ بِمُقَدَّمِ رَأْسِهِ، حَتَّى ذَهَبَ بِهِمَا إِلَى قَفَاهُ، ثُمَّ رَدَّهُمَا إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ، ثُمَّ غَسَلَ رِجْلَيْهِ‏.‏\hadithno{185}\hadithtrans{Narrated Yahya Al-Mazini:A person asked `Abdullah bin Zaid who was the grandfather of `Amr bin Yahya, "Can you show me how Allah's Messenger (ﷺ) used to perform ablution?" `Abdullah bin Zaid replied in the affirmative and asked for water. He poured it on his hands and washed them twice, then he rinsed his mouth thrice and washed his nose with water thrice by putting water in it and blowing it out. He washed his face thrice and after that he washed his forearms up to the elbows twice and then passed his wet hands over his head from its front to its back and vice versa (beginning from the front and taking them to the back of his head up to the nape of the neck and then brought them to the front again from where he had started) and washed his feet (up to the ankles)}}
\hadithdefcmd{bukhari}{186}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عَمْرٍو، عَنْ أَبِيهِ، شَهِدْتُ عَمْرَو بْنَ أَبِي حَسَنٍ سَأَلَ عَبْدَ اللَّهِ بْنَ زَيْدٍ عَنْ وُضُوءِ النَّبِيِّ، صلى الله عليه وسلم فَدَعَا بِتَوْرٍ مِنْ مَاءٍ، فَتَوَضَّأَ لَهُمْ وُضُوءَ النَّبِيِّ صلى الله عليه وسلم فَأَكْفَأَ عَلَى يَدِهِ مِنَ التَّوْرِ، فَغَسَلَ يَدَيْهِ ثَلاَثًا، ثُمَّ أَدْخَلَ يَدَهُ فِي التَّوْرِ، فَمَضْمَضَ وَاسْتَنْشَقَ وَاسْتَنْثَرَ ثَلاَثَ غَرَفَاتٍ، ثُمَّ أَدْخَلَ يَدَهُ فَغَسَلَ وَجْهَهُ ثَلاَثًا، ثُمَّ أَدْخَلَ يَدَهُ فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ إِلَى الْمِرْفَقَيْنِ مَرَّتَيْنِ، ثُمَّ أَدْخَلَ يَدَهُ فَمَسَحَ رَأْسَهُ، فَأَقْبَلَ بِهِمَا وَأَدْبَرَ مَرَّةً وَاحِدَةً، ثُمَّ غَسَلَ رِجْلَيْهِ إِلَى الْكَعْبَيْنِ‏.‏\hadithno{186}\hadithtrans{Narrated `Amr:My father saw `Amr bin Abi Hasan asking `Abdullah bin Zaid about the ablution of the Prophet. `Abdullah bin Zaid asked for earthenware pot containing water and in front of them performed ablution like that of the Prophet (ﷺ) . He poured water from the pot over his hand and washed his hands thrice and then he put his hands in the pot and rinsed his mouth and washed his nose by putting water in it and then blowing it out with three handfuls of water. Again he put his hand in the water and washed his face thrice and washed his forearms up to the elbows twice; and then put his hands in the water and then passed them over his head by bringing them to the front and then to the rear of the head once, and then he washed his feet up to the ankles}}
\hadithdefcmd{bukhari}{187}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، يَقُولُ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْهَاجِرَةِ، فَأُتِيَ بِوَضُوءٍ فَتَوَضَّأَ، فَجَعَلَ النَّاسُ يَأْخُذُونَ مِنْ فَضْلِ وَضُوئِهِ فَيَتَمَسَّحُونَ بِهِ، فَصَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ رَكْعَتَيْنِ وَالْعَصْرَ رَكْعَتَيْنِ، وَبَيْنَ يَدَيْهِ عَنَزَةٌ‏.‏\hadithno{187}\hadithtrans{Narrated Abu Juhaifa:Allah's Messenger (ﷺ) came to us at noon and water for ablution was brought to him. After he had performed ablution, the remaining water was taken by the people and they started smearing their bodies with it (as a blessed thing). The Prophet (ﷺ) offered two rak`at of the Zuhr prayer and then two rak`at of the `Asr prayer while a short spear (or stick) was there (as a Sutra) in front of him}}
\hadithdefcmd{bukhari}{188}{وَقَالَ أَبُو مُوسَى دَعَا النَّبِيُّ صلى الله عليه وسلم بِقَدَحٍ فِيهِ مَاءٌ، فَغَسَلَ يَدَيْهِ وَوَجْهَهُ فِيهِ، وَمَجَّ فِيهِ ثُمَّ قَالَ لَهُمَا اشْرَبَا مِنْهُ، وَأَفْرِغَا عَلَى وُجُوهِكُمَا وَنُحُورِكُمَا‏.‏\hadithno{188}\hadithtrans{Abu Musa said:The Prophet asked for a tumbler containing water and washed both his hands and face in it and then threw a mouthful of water in the tumbler and said to both of us (Abu Musa and Bilal), "Drink from the tumbler and pour some of its water on your faces and chests}}
\hadithdefcmd{bukhari}{189}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، قَالَ وَهُوَ الَّذِي مَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي وَجْهِهِ وَهْوَ غُلاَمٌ مِنْ بِئْرِهِمْ‏.‏ وَقَالَ عُرْوَةُ عَنِ الْمِسْوَرِ وَغَيْرِهِ يُصَدِّقُ كُلُّ وَاحِدٍ مِنْهُمَا صَاحِبَهُ وَإِذَا تَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم كَادُوا يَقْتَتِلُونَ عَلَى وَضُوئِهِ‏.‏\hadithno{189}\hadithtrans{Narrated Ibn Shihab:Mahmud bin Ar-Rabi` who was the person on whose face the Prophet (ﷺ) had ejected a mouthful of water from his family's well while he was a boy, and `Urwa (on the authority of Al-Miswar and others) who testified each other, said, "Whenever the Prophet (ﷺ) , performed ablution, his companions were nearly fighting for the remains of the water}}
\hadithdefcmd{bukhari}{190}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يُونُسَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنِ الْجَعْدِ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ ذَهَبَتْ بِي خَالَتِي إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ، إِنَّ ابْنَ أُخْتِي وَجِعٌ‏.‏ فَمَسَحَ رَأْسِي وَدَعَا لِي بِالْبَرَكَةِ، ثُمَّ تَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ، ثُمَّ قُمْتُ خَلْفَ ظَهْرِهِ، فَنَظَرْتُ إِلَى خَاتَمِ النُّبُوَّةِ بَيْنَ كَتِفَيْهِ مِثْلِ زِرِّ الْحَجَلَةِ‏.‏\hadithno{190}\hadithtrans{Narrated As-Sa'ib bin Yazid:My aunt took me to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! This son of my sister has got a disease in his legs." So he passed his hands on my head and prayed for Allah's blessings for me; then he performed ablution and I drank from the remaining water. I stood behind him and saw the seal of Prophethood between his shoulders, and it was like the "Zir-al-Hijla" (means the button of a small tent, but some said 'egg of a partridge.' etc)}}
\hadithdefcmd{bukhari}{191}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّهُ أَفْرَغَ مِنَ الإِنَاءِ عَلَى يَدَيْهِ فَغَسَلَهُمَا، ثُمَّ غَسَلَ أَوْ مَضْمَضَ، وَاسْتَنْشَقَ مِنْ كَفَّةٍ وَاحِدَةٍ، فَفَعَلَ ذَلِكَ ثَلاَثًا، فَغَسَلَ يَدَيْهِ إِلَى الْمِرْفَقَيْنِ مَرَّتَيْنِ مَرَّتَيْنِ، وَمَسَحَ بِرَأْسِهِ مَا أَقْبَلَ وَمَا أَدْبَرَ، وَغَسَلَ رِجْلَيْهِ إِلَى الْكَعْبَيْنِ، ثُمَّ قَالَ هَكَذَا وُضُوءُ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{191}\hadithtrans{Narrated `Amr bin Yahya:(on the authority of his father) `Abdullah bin Zaid poured water on his hands from a utensil containing water and washed them and then with one handful of water he rinsed his mouth and cleaned his nose by putting water in it and then blowing it out. He repeated it thrice. He, then, washed his hands and forearms up to the elbows twice and passed wet hands over his head, both forwards and backwards, and washed his feet up to the ankles and said, "This is the ablution of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{192}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، قَالَ شَهِدْتُ عَمْرَو بْنَ أَبِي حَسَنٍ سَأَلَ عَبْدَ اللَّهِ بْنَ زَيْدٍ عَنْ وُضُوءِ النَّبِيِّ، صلى الله عليه وسلم فَدَعَا بِتَوْرٍ مِنْ مَاءٍ، فَتَوَضَّأَ لَهُمْ، فَكَفَأَ عَلَى يَدَيْهِ فَغَسَلَهُمَا ثَلاَثًا، ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ، فَمَضْمَضَ وَاسْتَنْشَقَ، وَاسْتَنْثَرَ ثَلاَثًا بِثَلاَثِ غَرَفَاتٍ مِنْ مَاءٍ، ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ، فَغَسَلَ وَجْهَهُ ثَلاَثًا، ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ، فَغَسَلَ يَدَيْهِ إِلَى الْمِرْفَقَيْنِ مَرَّتَيْنِ مَرَّتَيْنِ، ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ، فَمَسَحَ بِرَأْسِهِ فَأَقْبَلَ بِيَدَيْهِ وَأَدْبَرَ بِهِمَا، ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ فَغَسَلَ رِجْلَيْهِ‏.‏ وَحَدَّثَنَا مُوسَى قَالَ حَدَّثَنَا وُهَيْبٌ قَالَ مَسَحَ رَأْسَهُ مَرَّةً‏.‏\hadithno{192}\hadithtrans{Narrated `Amr bin Yahya:My father said, "I saw `Amr bin Abi Hasan asking `Abdullah bin Zaid about the ablution of the Prophet. `Abdullah bin Zaid asked for an earthenware pot containing water and performed ablution in front of them. He poured water over his hands and washed them thrice. Then he put his (right) hand in the pot and rinsed his mouth and washed his nose by putting water in it and then blowing it out thrice with three handfuls of water Again he put his hand in the water and washed his face thrice. After that he put his hand in the pot and washed his forearms up to the elbows twice and then again put his hand in the water and passed wet hands over his head by bringing them to the front and then to the back and once more he put his hand in the pot and washed his feet (up to the ankles.)" Narrated Wuhaib: That he (the Prophet (ﷺ) in narration 191 above) had passed his wet hands on the head once only}}
\hadithdefcmd{bukhari}{193}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ كَانَ الرِّجَالُ وَالنِّسَاءُ يَتَوَضَّئُونَ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم جَمِيعًا‏.‏\hadithno{193}\hadithtrans{Narrated 'Abdullah bin 'Umar:"During the lifetime of Allah's Messenger (ﷺ) men and women used to perform ablution together}}
\hadithdefcmd{bukhari}{194}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي، وَأَنَا مَرِيضٌ لاَ أَعْقِلُ، فَتَوَضَّأَ وَصَبَّ عَلَىَّ مِنْ وَضُوئِهِ، فَعَقَلْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ لِمَنِ الْمِيرَاثُ إِنَّمَا يَرِثُنِي كَلاَلَةٌ‏.‏ فَنَزَلَتْ آيَةُ الْفَرَائِضِ‏.‏\hadithno{194}\hadithtrans{Narrated Jabir:Allah's Messenger (ﷺ) came to visit me while I was sick and unconscious. He performed ablution and sprinkled the remaining water on me and I became conscious and said, "O Allah's Messenger (ﷺ)! To whom will my inheritance go as I have neither ascendants nor descendants?" Then the Divine verses regarding Fara'id (inheritance) were revealed}}
\hadithdefcmd{bukhari}{195}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ بَكْرٍ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ حَضَرَتِ الصَّلاَةُ، فَقَامَ مَنْ كَانَ قَرِيبَ الدَّارِ إِلَى أَهْلِهِ، وَبَقِيَ قَوْمٌ، فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِخْضَبٍ مِنْ حِجَارَةٍ فِيهِ مَاءٌ، فَصَغُرَ الْمِخْضَبُ أَنْ يَبْسُطَ فِيهِ كَفَّهُ، فَتَوَضَّأَ الْقَوْمُ كُلُّهُمْ‏.‏ قُلْنَا كَمْ كُنْتُمْ قَالَ ثَمَانِينَ وَزِيَادَةً‏.‏\hadithno{195}\hadithtrans{Narrated Anas:It was the time for prayer, and those whose houses were near got up and went to their people (to perform ablution), and there remained some people (sitting). Then a painted stove pot (Mikhdab) containing water was brought to Allah's Messenger (ﷺ). The pot was small, not broad enough for one to spread one's hand in; yet all the people performed ablution. (The sub narrator said, "We asked Anas, 'How many persons were you?' Anas replied 'We were eighty or more"). (It was one of the miracles of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{196}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَعَا بِقَدَحٍ فِيهِ مَاءٌ، فَغَسَلَ يَدَيْهِ وَوَجْهَهُ فِيهِ وَمَجَّ فِيهِ‏.‏\hadithno{196}\hadithtrans{Narrated Abu Musa:Once the Prophet (ﷺ) asked for a tumbler containing water. He washed his hands and face in it and also threw a mouthful of water in it}}
\hadithdefcmd{bukhari}{197}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْرَجْنَا لَهُ مَاءً فِي تَوْرٍ مِنْ صُفْرٍ فَتَوَضَّأَ، فَغَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَيْهِ مَرَّتَيْنِ مَرَّتَيْنِ، وَمَسَحَ بِرَأْسِهِ فَأَقْبَلَ بِهِ وَأَدْبَرَ، وَغَسَلَ رِجْلَيْهِ‏.‏\hadithno{197}\hadithtrans{Narrated `Abdullah bin Zaid:Once Allah's Messenger (ﷺ) came to us and we brought out water for him in a brass pot. He performed ablution thus: He washed his face thrice, and his forearms to the elbows twice, then passed his wet hands lightly over the head from front to rear and brought them to front again and washed his feet (up to the ankles)}}
\hadithdefcmd{bukhari}{198}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، قَالَتْ لَمَّا ثَقُلَ النَّبِيُّ صلى الله عليه وسلم وَاشْتَدَّ بِهِ وَجَعُهُ، اسْتَأْذَنَ أَزْوَاجَهُ فِي أَنْ يُمَرَّضَ فِي بَيْتِي، فَأَذِنَّ لَهُ، فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ رَجُلَيْنِ تَخُطُّ رِجْلاَهُ فِي الأَرْضِ بَيْنَ عَبَّاسٍ وَرَجُلٍ آخَرَ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَأَخْبَرْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ فَقَالَ أَتَدْرِي مَنِ الرَّجُلُ الآخَرُ قُلْتُ لاَ‏.‏ قَالَ هُوَ عَلِيٌّ‏.‏ وَكَانَتْ عَائِشَةُ ـ رضى الله عنها ـ تُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ بَعْدَ مَا دَخَلَ بَيْتَهُ وَاشْتَدَّ وَجَعُهُ ‏ "‏ هَرِيقُوا عَلَىَّ مِنْ سَبْعِ قِرَبٍ، لَمْ تُحْلَلْ أَوْكِيَتُهُنَّ، لَعَلِّي أَعْهَدُ إِلَى النَّاسِ ‏"‏‏.‏ وَأُجْلِسَ فِي مِخْضَبٍ لِحَفْصَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم، ثُمَّ طَفِقْنَا نَصُبُّ عَلَيْهِ تِلْكَ حَتَّى طَفِقَ يُشِيرُ إِلَيْنَا أَنْ قَدْ فَعَلْتُنَّ، ثُمَّ خَرَجَ إِلَى النَّاسِ‏.‏\hadithno{198}\hadithtrans{Narrated `Aisha:When the ailment of the Prophet (ﷺ) became aggravated and his disease became severe, he asked his wives to permit him to be nursed (treated) in my house. So they gave him the permission. Then the Prophet came (to my house) with the support of two men, and his legs were dragging on the ground, between `Abbas, and another man." 'Ubaidullah (the sub narrator) said, "I informed `Abdullah bin `Abbas of what `Aisha said. Ibn `Abbas said: 'Do you know who was the other man?' I replied in the negative. Ibn `Abbas said, 'He was `Ali (bin Abi Talib)." `Aisha further said, "When the Prophet (ﷺ) came to my house and his sickness became aggravated he ordered us to pour seven skins full of water on him, so that he might give some advice to the people. So he was seated in a Mikhdab (brass tub) belonging to Hafsa, the wife of the Prophet. Then, all of us started pouring water on him from the water skins till he beckoned to us to stop and that we have done (what he wanted us to do). After that he went out to the people}}
\hadithdefcmd{bukhari}{199}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، قَالَ كَانَ عَمِّي يُكْثِرُ مِنَ الْوُضُوءِ، قَالَ لِعَبْدِ اللَّهِ بْنِ زَيْدٍ أَخْبِرْنِي كَيْفَ رَأَيْتَ النَّبِيَّ صلى الله عليه وسلم يَتَوَضَّأُ فَدَعَا بِتَوْرٍ مِنْ مَاءٍ، فَكَفَأَ عَلَى يَدَيْهِ فَغَسَلَهُمَا ثَلاَثَ مِرَارٍ، ثُمَّ أَدْخَلَ يَدَهُ فِي التَّوْرِ، فَمَضْمَضَ وَاسْتَنْثَرَ ثَلاَثَ مَرَّاتٍ مِنْ غَرْفَةٍ وَاحِدَةٍ، ثُمَّ أَدْخَلَ يَدَهُ فَاغْتَرَفَ بِهَا فَغَسَلَ وَجْهَهُ ثَلاَثَ مَرَّاتٍ، ثُمَّ غَسَلَ يَدَيْهِ إِلَى الْمِرْفَقَيْنِ مَرَّتَيْنِ مَرَّتَيْنِ، ثُمَّ أَخَذَ بِيَدِهِ مَاءً، فَمَسَحَ رَأْسَهُ، فَأَدْبَرَ بِيَدَيْهِ وَأَقْبَلَ ثُمَّ غَسَلَ رِجْلَيْهِ، فَقَالَ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَوَضَّأُ‏.‏\hadithno{199}\hadithtrans{Narrated `Amr bin Yahya:(on the authority of his father) My uncle used to perform ablution extravagantly and once he asked `Abdullah bin Zaid to tell him how he had seen the Prophet (ﷺ) performing ablution. He asked for an earthenware pot containing water, and poured water from it on his hands and washed them thrice, and then put his hand in the earthenware pot and rinsed his mouth and washed his nose by putting water in it and then blowing it out thrice with one handful of water; he again put his hand in the water and took a handful of water and washed his face thrice, then washed his hands up to the elbows twice, and took water with his hand, and passed it over his head from front to back and then from back to front, and then washed his feet (up to the ankles) and said, "I saw the Prophet (ﷺ) performing ablution in that way}}
\hadithdefcmd{bukhari}{200}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَعَا بِإِنَاءٍ مِنْ مَاءٍ، فَأُتِيَ بِقَدَحٍ رَحْرَاحٍ فِيهِ شَىْءٌ مِنْ مَاءٍ، فَوَضَعَ أَصَابِعَهُ فِيهِ‏.‏ قَالَ أَنَسٌ فَجَعَلْتُ أَنْظُرُ إِلَى الْمَاءِ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِهِ، قَالَ أَنَسٌ فَحَزَرْتُ مَنْ تَوَضَّأَ مَا بَيْنَ السَّبْعِينَ إِلَى الثَّمَانِينَ‏.‏\hadithno{200}\hadithtrans{Narrated Thabit:Anas said, "The Prophet (ﷺ) asked for water and a tumbler with a broad base and not so deep, containing a small quantity of water, was brought to him whereby he put his fingers in it." Anas further said, 'I noticed the water springing out from amongst his fingers.' Anas added, 'I estimated that the people who performed ablution with it numbered between seventy to eighty}}
\hadithdefcmd{bukhari}{201}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مِسْعَرٌ، قَالَ حَدَّثَنِي ابْنُ جَبْرٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَغْسِلُ ـ أَوْ كَانَ يَغْتَسِلُ ـ بِالصَّاعِ إِلَى خَمْسَةِ أَمْدَادٍ، وَيَتَوَضَّأُ بِالْمُدِّ‏.‏\hadithno{201}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to take a bath with one Sa` up to five Mudds (1 Sa` = [??] Mudds) of water and used to perform ablution with one Mudd of water}}
\hadithdefcmd{bukhari}{202}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ الْمِصْرِيُّ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنِي عَمْرٌو، حَدَّثَنِي أَبُو النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَسَحَ عَلَى الْخُفَّيْنِ‏.‏ وَأَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ سَأَلَ عُمَرَ عَنْ ذَلِكَ فَقَالَ نَعَمْ إِذَا حَدَّثَكَ شَيْئًا سَعْدٌ عَنِ النَّبِيِّ صلى الله عليه وسلم فَلاَ تَسْأَلْ عَنْهُ غَيْرَهُ‏.‏ وَقَالَ مُوسَى بْنُ عُقْبَةَ أَخْبَرَنِي أَبُو النَّضْرِ أَنَّ أَبَا سَلَمَةَ أَخْبَرَهُ أَنَّ سَعْدًا حَدَّثَهُ فَقَالَ عُمَرُ لِعَبْدِ اللَّهِ‏.‏ نَحْوَهُ‏.‏\hadithno{202}\hadithtrans{Narrated `Abdullah bin `Umar:Sa`d bin Abi Waqqas said, "The Prophet (ﷺ) passed wet hands over his Khuffs (socks made from thick fabric or leather)." `Abdullah bin `Umar asked `Umar about it. `Umar replied in the affirmative and added, "Whenever Sa`d narrates a Hadith from the Prophet, there is no need to ask anyone else about it}}
\hadithdefcmd{bukhari}{203}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ خَرَجَ لِحَاجَتِهِ فَاتَّبَعَهُ الْمُغِيرَةُ بِإِدَاوَةٍ فِيهَا مَاءٌ، فَصَبَّ عَلَيْهِ حِينَ فَرَغَ مِنْ حَاجَتِهِ، فَتَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ‏.‏\hadithno{203}\hadithtrans{Narrated Al-Mughira bin Shu`ba:Once Allah's Messenger (ﷺ) went out to answer the call of nature and I followed him with a tumbler containing water, and when he finished, I poured water and he performed ablution and passed wet hands over his Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{204}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، رَأَى النَّبِيَّ صلى الله عليه وسلم يَمْسَحُ عَلَى الْخُفَّيْنِ‏.‏ وَتَابَعَهُ حَرْبُ بْنُ شَدَّادٍ وَأَبَانُ عَنْ يَحْيَى‏.‏\hadithno{204}\hadithtrans{Narrated Ja`far bin `Amr bin Umaiya Ad-Damri:My father said, "I saw the Prophet (ﷺ) passing wet hands over his Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{205}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ جَعْفَرِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَمْسَحُ عَلَى عِمَامَتِهِ وَخُفَّيْهِ‏.‏ وَتَابَعَهُ مَعْمَرٌ عَنْ يَحْيَى عَنْ أَبِي سَلَمَةَ عَنْ عَمْرٍو قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{205}\hadithtrans{Narrated Ja`far bin `Amr:My father said, "I saw the Prophet (ﷺ) passing wet hands over his turban and Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{206}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ، فَأَهْوَيْتُ لأَنْزِعَ خُفَّيْهِ فَقَالَ ‏ "‏ دَعْهُمَا، فَإِنِّي أَدْخَلْتُهُمَا طَاهِرَتَيْنِ ‏"‏‏.‏ فَمَسَحَ عَلَيْهِمَا‏.‏\hadithno{206}\hadithtrans{Narrated `Urwa bin Al-Mughira:My father said, "Once I was in the company of the Prophet (ﷺ) on a journey and I dashed to take off his Khuffs (socks made from thick fabric or leather). He ordered me to leave them as he had put them after performing ablution. So he passed wet hands over them}}
\hadithdefcmd{bukhari}{207}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ،‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ كَتِفَ شَاةٍ، ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{207}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) ate a piece of cooked mutton from the shoulder region and prayed without repeating ablution}}
\hadithdefcmd{bukhari}{208}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفِ شَاةٍ، فَدُعِيَ إِلَى الصَّلاَةِ فَأَلْقَى السِّكِّينَ فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{208}\hadithtrans{Narrated Ja`far bin `Amr bin Umaiya:My father said, "I saw Allah's Messenger (ﷺ) taking a piece of (cooked) mutton from the shoulder region and then he was called for prayer. He put his knife down and prayed without repeating ablution}}
\hadithdefcmd{bukhari}{209}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ سُوَيْدَ بْنَ النُّعْمَانِ، أَخْبَرَهُ‏.‏ أَنَّهُ، خَرَجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ، حَتَّى إِذَا كَانُوا بِالصَّهْبَاءِ ـ وَهِيَ أَدْنَى خَيْبَرَ ـ فَصَلَّى الْعَصْرَ، ثُمَّ دَعَا بِالأَزْوَادِ، فَلَمْ يُؤْتَ إِلاَّ بِالسَّوِيقِ، فَأَمَرَ بِهِ فَثُرِّيَ، فَأَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَكَلْنَا، ثُمَّ قَامَ إِلَى الْمَغْرِبِ، فَمَضْمَضَ وَمَضْمَضْنَا، ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{209}\hadithtrans{Narrated Suwaid bin Al-Nu`man:In the year of the conquest of Khaibar I went with Allah's Messenger (ﷺ) till we reached Sahba, a place near Khaibar, where Allah's Messenger (ﷺ) offered the `Asr prayer and asked for food. Nothing but saweeq was brought. He ordered it to be moistened with water. He and all of us ate it and the Prophet (ﷺ) got up for the evening prayer (Maghrib prayer), rinsed his mouth with water and we did the same, and he then prayed without repeating the ablution}}
\hadithdefcmd{bukhari}{210}{وَحَدَّثَنَا أَصْبَغُ، قَالَ أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَكَلَ عِنْدَهَا كَتِفًا، ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{210}\hadithtrans{Narrated Maimuna:The Prophet (ﷺ) ate (a piece of) mutton from the shoulder region and then prayed without repeating the ablution}}
\hadithdefcmd{bukhari}{211}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شَرِبَ لَبَنًا، فَمَضْمَضَ وَقَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏‏.‏ تَابَعَهُ يُونُسُ وَصَالِحُ بْنُ كَيْسَانَ عَنِ الزُّهْرِيِّ‏.‏\hadithno{211}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) drank milk, rinsed his mouth and said, "It has fat}}
\hadithdefcmd{bukhari}{212}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ وَهُوَ يُصَلِّي فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ، فَإِنَّ أَحَدَكُمْ إِذَا صَلَّى وَهُوَ نَاعِسٌ لاَ يَدْرِي لَعَلَّهُ يَسْتَغْفِرُ فَيَسُبَّ نَفْسَهُ ‏"‏‏.‏\hadithno{212}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "If anyone of you feels drowsy while praying he should go to bed (sleep) till his slumber is over because in praying while drowsy one does not know whether one is asking for forgiveness or for a bad thing for oneself}}
\hadithdefcmd{bukhari}{213}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَنَمْ حَتَّى يَعْلَمَ مَا يَقْرَأُ ‏"‏‏.‏\hadithno{213}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "If anyone of you feels drowsy while praying, he should sleep till he understands what he is saying (reciting)}}
\hadithdefcmd{bukhari}{214}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ عَامِرٍ، قَالَ سَمِعْتُ أَنَسًا، ح قَالَ وَحَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ عَامِرٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ عِنْدَ كُلِّ صَلاَةٍ‏.‏ قُلْتُ كَيْفَ كُنْتُمْ تَصْنَعُونَ قَالَ يُجْزِئُ أَحَدَنَا الْوُضُوءُ مَا لَمْ يُحْدِثْ‏.‏\hadithno{214}\hadithtrans{Narrated `Amr bin `Amir:Anas said, "The Prophet (ﷺ) used to perform ablution for every prayer." I asked Anas, "What did you used to do?' Anas replied, "We used to pray with the same ablution until we break it with Hadath}}
\hadithdefcmd{bukhari}{215}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، قَالَ أَخْبَرَنِي سُوَيْدُ بْنُ النُّعْمَانِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ، حَتَّى إِذَا كُنَّا بِالصَّهْبَاءِ، صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ، فَلَمَّا صَلَّى دَعَا بِالأَطْعِمَةِ، فَلَمْ يُؤْتَ إِلاَّ بِالسَّوِيقِ، فَأَكَلْنَا وَشَرِبْنَا، ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمَغْرِبِ فَمَضْمَضَ، ثُمَّ صَلَّى لَنَا الْمَغْرِبَ وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{215}\hadithtrans{Narrated Suwaid bin Nu`man:In the year of the conquest of Khaibar I went with Allah's Messenger (ﷺ) till we reached As-Sahba' where Allah's Messenger (ﷺ) led the `Asr prayer and asked for the food. Nothing but saweeq was brought and we ate it and drank (water). The Prophet (ﷺ) got up for the (Maghrib) Prayer, rinsed his mouth with water and then led the prayer without repeating the ablution}}
\hadithdefcmd{bukhari}{216}{حَدَّثَنَا عُثْمَانُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِحَائِطٍ مِنْ حِيطَانِ الْمَدِينَةِ أَوْ مَكَّةَ، فَسَمِعَ صَوْتَ إِنْسَانَيْنِ يُعَذَّبَانِ فِي قُبُورِهِمَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يُعَذَّبَانِ، وَمَا يُعَذَّبَانِ فِي كَبِيرٍ ‏"‏، ثُمَّ قَالَ ‏"‏ بَلَى، كَانَ أَحَدُهُمَا لاَ يَسْتَتِرُ مِنْ بَوْلِهِ، وَكَانَ الآخَرُ يَمْشِي بِالنَّمِيمَةِ ‏"‏‏.‏ ثُمَّ دَعَا بِجَرِيدَةٍ فَكَسَرَهَا كِسْرَتَيْنِ، فَوَضَعَ عَلَى كُلِّ قَبْرٍ مِنْهُمَا كِسْرَةً‏.‏ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ لِمَ فَعَلْتَ هَذَا قَالَ ‏"‏ لَعَلَّهُ أَنْ يُخَفَّفَ عَنْهُمَا مَا لَمْ تَيْبَسَا أَوْ إِلَى أَنْ يَيْبَسَا ‏"‏‏.‏\hadithno{216}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet, while passing through one of the graveyards of Medina or Mecca heard the voices of two persons who were being tortured in their graves. The Prophet (ﷺ) said, "These two persons are being tortured not for a major sin (to avoid)." The Prophet (ﷺ) then added, "Yes! (they are being tortured for a major sin). Indeed, one of them never saved himself from being soiled with his urine while the other used to go about with calumnies (to make enmity between friends). The Prophet (ﷺ) then asked for a green leaf of a date-palm tree, broke it into two pieces and put one on each grave. On being asked why he had done so, he replied, "I hope that their torture might be lessened, till these get dried}}
\hadithdefcmd{bukhari}{217}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي رَوْحُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي مَيْمُونَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا تَبَرَّزَ لِحَاجَتِهِ أَتَيْتُهُ بِمَاءٍ فَيَغْسِلُ بِهِ‏.‏\hadithno{217}\hadithtrans{Narrated Anas bin Malik:Whenever the Prophet (ﷺ) went to answer the call of nature, I used to bring water with which he used to clean his private parts}}
\hadithdefcmd{bukhari}{218}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِقَبْرَيْنِ فَقَالَ ‏"‏ إِنَّهُمَا لَيُعَذَّبَانِ، وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَكَانَ لاَ يَسْتَتِرُ مِنَ الْبَوْلِ، وَأَمَّا الآخَرُ فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏‏.‏ ثُمَّ أَخَذَ جَرِيدَةً رَطْبَةً، فَشَقَّهَا نِصْفَيْنِ، فَغَرَزَ فِي كُلِّ قَبْرٍ وَاحِدَةً‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، لِمَ فَعَلْتَ هَذَا قَالَ ‏"‏ لَعَلَّهُ يُخَفَّفُ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏‏.‏ قَالَ ابْنُ الْمُثَنَّى وَحَدَّثَنَا وَكِيعٌ قَالَ حَدَّثَنَا الأَعْمَشُ قَالَ سَمِعْتُ مُجَاهِدًا مِثْلَهُ ‏"‏ يَسْتَتِرُ مِنْ بَوْلِهِ ‏"‏‏.‏\hadithno{218}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once passed by two graves and said, "These two persons are being tortured not for a major sin (to avoid). One of them never saved himself from being soiled with his urine, while the other used to go about with calumnies (to make enmity between friends)." The Prophet (ﷺ) then took a green leaf of a date-palm tree, split it into (pieces) and fixed one on each grave. They said, "O Allah's Apostle! Why have you done so?" He replied, "I hope that their punishment might be lessened till these (the pieces of the leaf) become dry." (See the footnote of Hadith)}}
\hadithdefcmd{bukhari}{219}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا هَمَّامٌ، أَخْبَرَنَا إِسْحَاقُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى أَعْرَابِيًّا يَبُولُ فِي الْمَسْجِدِ فَقَالَ ‏ "‏ دَعُوهُ ‏"‏‏.‏ حَتَّى إِذَا فَرَغَ دَعَا بِمَاءٍ فَصَبَّهُ عَلَيْهِ‏.‏\hadithno{219}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) saw a Bedouin making water in the mosque and told the people not to disturb him. When he finished, the Prophet (ﷺ) asked for some water and poured it over (the urine)}}
\hadithdefcmd{bukhari}{220}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَامَ أَعْرَابِيٌّ فَبَالَ فِي الْمَسْجِدِ فَتَنَاوَلَهُ النَّاسُ، فَقَالَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعُوهُ وَهَرِيقُوا عَلَى بَوْلِهِ سَجْلاً مِنْ مَاءٍ، أَوْ ذَنُوبًا مِنْ مَاءٍ، فَإِنَّمَا بُعِثْتُمْ مُيَسِّرِينَ، وَلَمْ تُبْعَثُوا مُعَسِّرِينَ ‏"‏‏.‏\hadithno{220}\hadithtrans{Narrated Abu Huraira:A Bedouin stood up and started making water in the mosque. The people caught him but the Prophet (ﷺ) ordered them to leave him and to pour a bucket or a tumbler of water over the place where he had passed the urine. The Prophet (ﷺ) then said, "You have been sent to make things easy and not to make them difficult}}
\hadithdefcmd{bukhari}{221}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{221}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said as above}}
\hadithdefcmd{bukhari}{222}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَبِيٍّ، فَبَالَ عَلَى ثَوْبِهِ، فَدَعَا بِمَاءٍ فَأَتْبَعَهُ إِيَّاهُ‏.‏\hadithno{222}\hadithtrans{Narrated `Aisha:(the mother of faithful believers) A child was brought to Allah's Messenger (ﷺ) and it urinated on the garment of the Prophet. The Prophet (ﷺ) asked for water and poured it over the soiled place}}
\hadithdefcmd{bukhari}{223}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أَنَّهَا أَتَتْ بِابْنٍ لَهَا صَغِيرٍ، لَمْ يَأْكُلِ الطَّعَامَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، فَأَجْلَسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حِجْرِهِ، فَبَالَ عَلَى ثَوْبِهِ، فَدَعَا بِمَاءٍ فَنَضَحَهُ وَلَمْ يَغْسِلْهُ‏.‏\hadithno{223}\hadithtrans{Narrated Um Qais bint Mihsin:I brought my young son, who had not started eating (ordinary food) to Allah's Messenger (ﷺ) who took him and made him sit in his lap. The child urinated on the garment of the Prophet, so he asked for water and poured it over the soiled (area) and did not wash it}}
\hadithdefcmd{bukhari}{224}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ أَتَى النَّبِيُّ صلى الله عليه وسلم سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا، ثُمَّ دَعَا بِمَاءٍ، فَجِئْتُهُ بِمَاءٍ فَتَوَضَّأَ‏.‏\hadithno{224}\hadithtrans{Narrated Hudhaifa:Once the Prophet (ﷺ) went to the dumps of some people and passed urine while standing. He then asked for water and so I brought it to him and he performed ablution}}
\hadithdefcmd{bukhari}{225}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ رَأَيْتُنِي أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم نَتَمَاشَى، فَأَتَى سُبَاطَةَ قَوْمٍ خَلْفَ حَائِطٍ، فَقَامَ كَمَا يَقُومُ أَحَدُكُمْ فَبَالَ، فَانْتَبَذْتُ مِنْهُ، فَأَشَارَ إِلَىَّ فَجِئْتُهُ، فَقُمْتُ عِنْدَ عَقِبِهِ حَتَّى فَرَغَ‏.‏\hadithno{225}\hadithtrans{Narrated Hudhaifa':The Prophet (ﷺ) and I walked till we reached the dumps of some people. He stood, as any one of you stands, behind a wall and urinated. I went away, but he beckoned me to come. So I approached him and stood near his back till he finished}}
\hadithdefcmd{bukhari}{226}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ كَانَ أَبُو مُوسَى الأَشْعَرِيُّ يُشَدِّدُ فِي الْبَوْلِ وَيَقُولُ إِنَّ بَنِي إِسْرَائِيلَ كَانَ إِذَا أَصَابَ ثَوْبَ أَحَدِهِمْ قَرَضَهُ‏.‏ فَقَالَ حُذَيْفَةُ لَيْتَهُ أَمْسَكَ، أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم سُبَاطَةَ قَوْمٍ فَبَالَ قَائِمًا‏.‏\hadithno{226}\hadithtrans{Narrated Abu Wail:Abu Musa Al-Ash`ari used to lay great stress on the question of urination and he used to say, "If anyone from Bani Israel happened to soil his clothes with urine, he used to cut that portion away." Hearing that, Hudhaifa said to Abu Wail, "I wish he (Abu Musa) didn't (lay great stress on that matter)." Hudhaifa added, "Allah's Messenger (ﷺ) went to the dumps of some people and urinated while standing}}
\hadithdefcmd{bukhari}{227}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَتْنِي فَاطِمَةُ، عَنْ أَسْمَاءَ، قَالَتْ جَاءَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ أَرَأَيْتَ إِحْدَانَا تَحِيضُ فِي الثَّوْبِ كَيْفَ تَصْنَعُ قَالَ ‏ "‏ تَحُتُّهُ، ثُمَّ تَقْرُصُهُ بِالْمَاءِ، وَتَنْضَحُهُ وَتُصَلِّي فِيهِ ‏"‏‏.‏\hadithno{227}\hadithtrans{Narrated Asma':A woman came to the Prophet (ﷺ) and said, "If anyone of us gets menses in her clothes then what should she do?" He replied, "She should (take hold of the soiled place), rub it and put it in the water and rub it in order to remove the traces of blood and then pour water over it. Then she can pray in it}}
\hadithdefcmd{bukhari}{228}{حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ ابْنَةُ أَبِي حُبَيْشٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ، أَفَأَدَعُ الصَّلاَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ، إِنَّمَا ذَلِكِ عِرْقٌ، وَلَيْسَ بِحَيْضٍ، فَإِذَا أَقْبَلَتْ حَيْضَتُكِ فَدَعِي الصَّلاَةَ، وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ ثُمَّ صَلِّي ‏"‏‏.‏ قَالَ وَقَالَ أَبِي ‏"‏ ثُمَّ تَوَضَّئِي لِكُلِّ صَلاَةٍ، حَتَّى يَجِيءَ ذَلِكَ الْوَقْتُ ‏"‏‏.‏\hadithno{228}\hadithtrans{Narrated `Aisha:Fatima bint Abi Hubaish came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ) I get persistent bleeding from the uterus and do not become clean. Shall I give up my prayers?" Allah's Messenger (ﷺ) replied, "No, because it is from a blood vessel and not the menses. So when your real menses begins give up your prayers and when it has finished wash off the blood (take a bath) and offer your prayers." Hisham (the sub narrator) narrated that his father had also said, (the Prophet (ﷺ) told her): "Perform ablution for every prayer till the time of the next period comes}}
\hadithdefcmd{bukhari}{229}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا عَمْرُو بْنُ مَيْمُونٍ الْجَزَرِيُّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْسِلُ الْجَنَابَةَ مِنْ ثَوْبِ النَّبِيِّ صلى الله عليه وسلم، فَيَخْرُجُ إِلَى الصَّلاَةِ، وَإِنَّ بُقَعَ الْمَاءِ فِي ثَوْبِهِ‏.‏\hadithno{229}\hadithtrans{Narrated `Aisha:I used to wash the traces of Janaba (semen) from the clothes of the Prophet (ﷺ) and he used to go for prayers while traces of water were still on it (water spots were still visible)}}
\hadithdefcmd{bukhari}{230}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا عَمْرٌو، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ عَائِشَةَ، ح وَحَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ مَيْمُونٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْمَنِيِّ، يُصِيبُ الثَّوْبَ فَقَالَتْ كُنْتُ أَغْسِلُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَيَخْرُجُ إِلَى الصَّلاَةِ وَأَثَرُ الْغَسْلِ فِي ثَوْبِهِ بُقَعُ الْمَاءِ‏.‏\hadithno{230}\hadithtrans{Narrated Sulaiman bin Yasar:I asked `Aisha about the clothes soiled with semen. She replied, "I used to wash it off the clothes of Allah's Messenger (ﷺ) and he would go for the prayer while water spots were still visible}}
\hadithdefcmd{bukhari}{231}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ مَيْمُونٍ، قَالَ سَأَلْتُ سُلَيْمَانَ بْنَ يَسَارٍ فِي الثَّوْبِ تُصِيبُهُ الْجَنَابَةُ قَالَ قَالَتْ عَائِشَةُ كُنْتُ أَغْسِلُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم، ثُمَّ يَخْرُجُ إِلَى الصَّلاَةِ وَأَثَرُ الْغَسْلِ فِيهِ بُقَعُ الْمَاءِ‏.‏\hadithno{231}\hadithtrans{Narrated `Amr bin Maimun:I heard Sulaiman bin Yasar talking about the clothes soiled with semen. He said that `Aisha had said, "I used to wash it off the clothes of Allah's Messenger (ﷺ) and he would go for the prayers while water spots were still visible on them}}
\hadithdefcmd{bukhari}{232}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا عَمْرُو بْنُ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَغْسِلُ الْمَنِيَّ مِنْ ثَوْبِ النَّبِيِّ صلى الله عليه وسلم، ثُمَّ أَرَاهُ فِيهِ بُقْعَةً أَوْ بُقَعًا‏.‏\hadithno{232}\hadithtrans{Narrated `Aishah:I used to wash the semen off the clothes of the Prophet (ﷺ) and even then I used to notice one or more spots on them}}
\hadithdefcmd{bukhari}{233}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ قَدِمَ أُنَاسٌ مِنْ عُكْلٍ أَوْ عُرَيْنَةَ، فَاجْتَوَوُا الْمَدِينَةَ، فَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم بِلِقَاحٍ، وَأَنْ يَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا، فَانْطَلَقُوا، فَلَمَّا صَحُّوا قَتَلُوا رَاعِيَ النَّبِيِّ صلى الله عليه وسلم وَاسْتَاقُوا النَّعَمَ، فَجَاءَ الْخَبَرُ فِي أَوَّلِ النَّهَارِ، فَبَعَثَ فِي آثَارِهِمْ، فَلَمَّا ارْتَفَعَ النَّهَارُ جِيءَ بِهِمْ، فَأَمَرَ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ، وَسُمِرَتْ أَعْيُنُهُمْ، وَأُلْقُوا فِي الْحَرَّةِ يَسْتَسْقُونَ فَلاَ يُسْقَوْنَ‏.‏ قَالَ أَبُو قِلاَبَةَ فَهَؤُلاَءِ سَرَقُوا وَقَتَلُوا وَكَفَرُوا بَعْدَ إِيمَانِهِمْ، وَحَارَبُوا اللَّهَ وَرَسُولَهُ‏.‏\hadithno{233}\hadithtrans{Narrated Abu Qilaba:Anas said, "Some people of `Ukl or `Uraina tribe came to Medina and its climate did not suit them. So the Prophet (ﷺ) ordered them to go to the herd of (Milch) camels and to drink their milk and urine (as a medicine). So they went as directed and after they became healthy, they killed the shepherd of the Prophet and drove away all the camels. The news reached the Prophet (ﷺ) early in the morning and he sent (men) in their pursuit and they were captured and brought at noon. He then ordered to cut their hands and feet (and it was done), and their eyes were branded with heated pieces of iron, They were put in 'Al-Harra' and when they asked for water, no water was given to them." Abu Qilaba said, "Those people committed theft and murder, became infidels after embracing Islam and fought against Allah and His Apostle}}
\hadithdefcmd{bukhari}{234}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنَا أَبُو التَّيَّاحِ، يَزِيدُ بْنُ حُمَيْدٍ عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي قَبْلَ أَنْ يُبْنَى الْمَسْجِدُ فِي مَرَابِضِ الْغَنَمِ‏.‏\hadithno{234}\hadithtrans{Narrated Anas:Prior to the construction of the mosque, the Prophet (ﷺ) offered the prayers at sheep-folds}}
\hadithdefcmd{bukhari}{235}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ فَأْرَةٍ سَقَطَتْ فِي سَمْنٍ فَقَالَ ‏ "‏ أَلْقُوهَا وَمَا حَوْلَهَا فَاطْرَحُوهُ‏.‏ وَكُلُوا سَمْنَكُمْ ‏"‏‏.‏\hadithno{235}\hadithtrans{Narrated Maimuna:Allah's Messenger (ﷺ) was asked regarding ghee (cooking butter) in which a mouse had fallen. He said, "Take out the mouse and throw away the ghee around it and use the rest}}
\hadithdefcmd{bukhari}{236}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ فَأْرَةٍ سَقَطَتْ فِي سَمْنٍ فَقَالَ ‏ "‏ خُذُوهَا وَمَا حَوْلَهَا فَاطْرَحُوهُ ‏"‏‏.‏ قَالَ مَعْنٌ حَدَّثَنَا مَالِكٌ مَا لاَ أُحْصِيهِ يَقُولُ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ‏.‏\hadithno{236}\hadithtrans{Narrated Maimuna:The Prophet (ﷺ) was asked regarding ghee in which a mouse had fallen. He said, "Take out the mouse and throw away the ghee around it (and use the rest)}}
\hadithdefcmd{bukhari}{237}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ كَلْمٍ يُكْلَمُهُ الْمُسْلِمُ فِي سَبِيلِ اللَّهِ يَكُونُ يَوْمَ الْقِيَامَةِ كَهَيْئَتِهَا إِذْ طُعِنَتْ، تَفَجَّرُ دَمًا، اللَّوْنُ لَوْنُ الدَّمِ، وَالْعَرْفُ عَرْفُ الْمِسْكِ ‏"‏‏.‏\hadithno{237}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A wound which a Muslim receives in Allah's cause will appear on the Day of Resurrection as it was at the time of infliction; blood will be flowing from the wound and its color will be that of the blood but will smell like musk}}
\hadithdefcmd{bukhari}{238}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، قَالَ أَخْبَرَنَا أَبُو الزِّنَادِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ هُرْمُزَ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَحْنُ الآخِرُونَ السَّابِقُونَ ‏"‏‏.‏\hadithno{238}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We (Muslims) are the last (people to come in the world) but (will be) the foremost (on the Day of Resurrection)}}
\hadithdefcmd{bukhari}{239}{وَبِإِسْنَادِهِ قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ الَّذِي لاَ يَجْرِي، ثُمَّ يَغْتَسِلُ فِيهِ ‏"‏‏.‏\hadithno{239}\hadithtrans{The same narrator said that the Prophet (ﷺ) had said: "You should not pass urine in stagnant water which is not flowing then (you may need to) wash in it}}
\hadithdefcmd{bukhari}{240}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم سَاجِدٌ ح قَالَ وَحَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ قَالَ حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ عَنْ أَبِيهِ عَنْ أَبِي إِسْحَاقَ قَالَ حَدَّثَنِي عَمْرُو بْنُ مَيْمُونٍ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي عِنْدَ الْبَيْتِ، وَأَبُو جَهْلٍ وَأَصْحَابٌ لَهُ جُلُوسٌ، إِذْ قَالَ بَعْضُهُمْ لِبَعْضٍ أَيُّكُمْ يَجِيءُ بِسَلَى جَزُورِ بَنِي فُلاَنٍ فَيَضَعُهُ عَلَى ظَهْرِ مُحَمَّدٍ إِذَا سَجَدَ فَانْبَعَثَ أَشْقَى الْقَوْمِ فَجَاءَ بِهِ، فَنَظَرَ حَتَّى إِذَا سَجَدَ النَّبِيُّ صلى الله عليه وسلم وَضَعَهُ عَلَى ظَهْرِهِ بَيْنَ كَتِفَيْهِ وَأَنَا أَنْظُرُ، لاَ أُغَيِّرُ شَيْئًا، لَوْ كَانَ لِي مَنْعَةٌ‏.‏ قَالَ فَجَعَلُوا يَضْحَكُونَ وَيُحِيلُ بَعْضُهُمْ عَلَى بَعْضٍ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم سَاجِدٌ لاَ يَرْفَعُ رَأْسَهُ، حَتَّى جَاءَتْهُ فَاطِمَةُ، فَطَرَحَتْ عَنْ ظَهْرِهِ، فَرَفَعَ رَأْسَهُ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ ‏"‏‏.‏ ثَلاَثَ مَرَّاتٍ، فَشَقَّ عَلَيْهِمْ إِذْ دَعَا عَلَيْهِمْ ـ قَالَ وَكَانُوا يُرَوْنَ أَنَّ الدَّعْوَةَ فِي ذَلِكَ الْبَلَدِ مُسْتَجَابَةٌ ـ ثُمَّ سَمَّى ‏"‏ اللَّهُمَّ عَلَيْكَ بِأَبِي جَهْلٍ، وَعَلَيْكَ بِعُتْبَةَ بْنِ رَبِيعَةَ، وَشَيْبَةَ بْنِ رَبِيعَةَ، وَالْوَلِيدِ بْنِ عُتْبَةَ، وَأُمَيَّةَ بْنِ خَلَفٍ، وَعُقْبَةَ بْنِ أَبِي مُعَيْطٍ ‏"‏‏.‏ وَعَدَّ السَّابِعَ فَلَمْ يَحْفَظْهُ قَالَ فَوَالَّذِي نَفْسِي بِيَدِهِ، لَقَدْ رَأَيْتُ الَّذِينَ عَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم صَرْعَى فِي الْقَلِيبِ قَلِيبِ بَدْرٍ‏.‏\hadithno{240}\hadithtrans{Narrated `Abdullah:While Allah's Messenger (ﷺ) was prostrating (as stated below). Narrated `Abdullah bin Mas`ud: Once the Prophet (ﷺ) was offering prayers at the Ka`ba. Abu Jahl was sitting with some of his companions. One of them said to the others, "Who amongst you will bring the Abdominal contents (intestines, etc.) of a camel of Bani so and so and put it on the back of Muhammad, when he prostrates?" The most unfortunate of them got up and brought it. He waited till the Prophet (ﷺ) prostrated and then placed it on his back between his shoulders. I was watching but could not do any thing. I wish I had some people with me to hold out against them. They started laughing and falling on one another. Allah's Messenger (ﷺ) was in prostration and he did not lift his head up till Fatima (Prophet's daughter) came and threw that (camel's Abdominal contents) away from his back. He raised his head and said thrice, "O Allah! Punish Quraish." So it was hard for Abu Jahl and his companions when the Prophet invoked Allah against them as they had a conviction that the prayers and invocations were accepted in this city (Mecca). The Prophet (ﷺ) said, "O Allah! Punish Abu Jahl, `Utba bin Rabi`a, Shaiba bin Rabi`a, Al-Walid bin `Utba, Umaiya bin Khalaf, and `Uqba bin Al Mu'it [??] (and he mentioned the seventh whose name I cannot recall). By Allah in Whose Hands my life is, I saw the dead bodies of those persons who were counted by Allah's Messenger (ﷺ) in the Qalib (one of the wells) of Badr}}
\hadithdefcmd{bukhari}{241}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ بَزَقَ النَّبِيُّ صلى الله عليه وسلم فِي ثَوْبِهِ‏.‏ طَوَّلَهُ ابْنُ أَبِي مَرْيَمَ قَالَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ حَدَّثَنِي حُمَيْدٌ قَالَ سَمِعْتُ أَنَسًا عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{241}\hadithtrans{Narrated Anas:The Prophet (ﷺ) once spat in his clothes}}
\hadithdefcmd{bukhari}{242}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏‏.‏\hadithno{242}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) said, "All drinks that produce intoxication are Haram (forbidden to drink)}}
\hadithdefcmd{bukhari}{243}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي حَازِمٍ، سَمِعَ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ،، وَسَأَلَهُ النَّاسُ، وَمَا بَيْنِي وَبَيْنَهُ أَحَدٌ بِأَىِّ شَىْءٍ دُووِيَ جُرْحُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَا بَقِيَ أَحَدٌ أَعْلَمُ بِهِ مِنِّي، كَانَ عَلِيٌّ يَجِيءُ بِتُرْسِهِ فِيهِ مَاءٌ، وَفَاطِمَةُ تَغْسِلُ عَنْ وَجْهِهِ الدَّمَ، فَأُخِذَ حَصِيرٌ فَأُحْرِقَ فَحُشِيَ بِهِ جُرْحُهُ‏.‏\hadithno{243}\hadithtrans{Narrated Abu Hazim:Sahl bin Sa`d As-Sa`idi, was asked by the people, "With what was the wound of the Prophet (ﷺ) treated?" Sahl replied, "None remains among the people living who knows that better than I. `Ali [??] used to bring water in his shield and Fatima used to wash the blood off his face. Then straw mat was burnt and the wound was filled with it}}
\hadithdefcmd{bukhari}{244}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَوَجَدْتُهُ يَسْتَنُّ بِسِوَاكٍ بِيَدِهِ يَقُولُ ‏ "‏ أُعْ أُعْ ‏"‏، وَالسِّوَاكُ فِي فِيهِ، كَأَنَّهُ يَتَهَوَّعُ‏.‏\hadithno{244}\hadithtrans{Narrated Abu Burda:My father said, "I came to the Prophet (ﷺ) and saw him carrying a Siwak in his hand and cleansing his teeth, saying, 'U' U'," as if he was retching while the Siwak was in his mouth}}
\hadithdefcmd{bukhari}{245}{حَدَّثَنَا عُثْمَانُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ يَشُوصُ فَاهُ بِالسِّوَاكِ‏.‏\hadithno{245}\hadithtrans{Narrated Hudhaifa:Whenever the Prophet (ﷺ) got up at night, he used to clean his mouth with Siwak}}
\hadithdefcmd{bukhari}{246}{وَقَالَ عَفَّانُ حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَرَانِي أَتَسَوَّكُ بِسِوَاكٍ، فَجَاءَنِي رَجُلاَنِ أَحَدُهُمَا أَكْبَرُ مِنَ الآخَرِ، فَنَاوَلْتُ السِّوَاكَ الأَصْغَرَ مِنْهُمَا، فَقِيلَ لِي كَبِّرْ‏.‏ فَدَفَعْتُهُ إِلَى الأَكْبَرِ مِنْهُمَا ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ اخْتَصَرَهُ نُعَيْمٌ عَنِ ابْنِ الْمُبَارَكِ عَنْ أُسَامَةَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ‏.‏\hadithno{246}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) said, "I dreamt that I was cleaning my teeth with a Siwak and two persons came to me. One of them was older than the other and I gave the Siwak to the younger. I was told that I should give it to the older and so I did}}
\hadithdefcmd{bukhari}{247}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا أَتَيْتَ مَضْجَعَكَ فَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ، ثُمَّ اضْطَجِعْ عَلَى شِقِّكَ الأَيْمَنِ، ثُمَّ قُلِ اللَّهُمَّ أَسْلَمْتُ وَجْهِي إِلَيْكَ، وَفَوَّضْتُ أَمْرِي إِلَيْكَ، وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ، رَغْبَةً وَرَهْبَةً إِلَيْكَ، لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ، اللَّهُمَّ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ، وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ‏.‏ فَإِنْ مُتَّ مِنْ لَيْلَتِكَ فَأَنْتَ عَلَى الْفِطْرَةِ، وَاجْعَلْهُنَّ آخِرَ مَا تَتَكَلَّمُ بِهِ ‏"‏‏.‏ قَالَ فَرَدَّدْتُهَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَلَمَّا بَلَغْتُ ‏"‏ اللَّهُمَّ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ ‏"‏‏.‏ قُلْتُ وَرَسُولِكَ‏.‏ قَالَ ‏"‏ لاَ، وَنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏‏.‏\hadithno{247}\hadithtrans{Narrated Al-Bara 'bin `Azib:The Prophet (ﷺ) said to me, "Whenever you go to bed perform ablution like that for the prayer, lie on your right side and say, "Allahumma aslamtu wajhi ilaika, wa fauwadtu `Amri ilaika, wa alja'tu Zahri ilaika raghbatan wa rahbatan ilaika. La Malja'a wa la manja minka illa ilaika. Allahumma amantu bikitabika-l-ladhi anzalta wa bina-biyika-l ladhi arsalta" (O Allah! I surrender to You and entrust all my affairs to You and depend upon You for Your Blessings both with hope and fear of You. There is no fleeing from You, and there is no place of protection and safety except with You O Allah! I believe in Your Book (the Qur'an) which You have revealed and in Your Prophet (Muhammad) whom You have sent). Then if you die on that very night, you will die with faith (i.e. on the religion of Islam). Let the aforesaid words be your last utterance (before sleep)." I repeated it before the Prophet (ﷺ) and when I reached "Allahumma amantu bikitabika-l-ladhi anzalta (O Allah I believe in Your Book which You have revealed)." I said, "Wa-rasulika (and your Apostle)." The Prophet (ﷺ) said, "No, (but say): 'Wanabiyika-l-ladhi arsalta (Your Prophet whom You have sent), instead}}
